function SegmentNuclei(ibase, isuff, f0, f1, fwidth, h, fname)
% SEGMENTNUCLEI: SegmentNuclei(ibase, isuff, f0, f1, fwidth, h, fname)
% 
% Produces an amira surface file representation of all the nuclei in the stack.
%
%INPUT:
%------
% ibase - image base name whole path including file name up to the numerical 
%         counter for stack level.
% isuff - image suffix eg .tif
% f0    - start frame
% f1    - end frame
% fwidth - width of frame number for fixed-width formats eg. 3 for img001.jpg
% h      - half width of depth averaging in other words the number of frames
%          above and below the frame to average.  eg 1 means average one 
%          frame above and one frame below.
% fname  - the complete filename including path to save the amira surface text file
%
% OUTPUT:
%---------
% a text file with filename fname that is the amira surface file representation.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% nucleus_stack.m
% zlink.m
% cell_objects.m
% triangulate_cell_objects.m
% write_HxSurface.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

n_steps = 5;
t = zeros(n_steps,1);

fprintf (1, 'Starting SegmentNuclei\n');
step = 1;
tic, F = nucleus_stack(ibase, isuff, f0, f1, fwidth, h); t(step) = toc;
fprintf (1, '  nucleus stack done: %f\n', t(step)); 

step = step+1;
tic, [L, num_objects] = zlink(F); t(step) = toc;
fprintf (1, '  z link done: %f\n', t(step)); 

step = step+1;
tic, B = cell_objects(F, L, num_objects); t(step) = toc;
fprintf ('  cell ojects done: %f\n', t(step));

step = step+1;
tic, [V, T, C, L] = triangulate_cell_objects(B); t(step) = toc;
fprintf (1, '  triangulation done: %f\n', t(step));

step = step+1;
tic, write_HxSurface(fname, V, T, C, L); t(step) = toc;
fprintf (1, '  write_HxSurface done %f\n', t(step));

fprintf (1, 'Total Elapsed Time = %f\n', sum(t));

