function f = arcresamp(e, ds, method);
%
% ARCRESAMP: f = arcresamp(e, ds, method);
%
% Uniformly resample a discrete curve (x,y) using arc length steps of size ds.
%
% INPUT:
% -----
% e      - (N X 2) matrix of (x,y) coords of points on the curve.
% ds     - arc length sampling rate
% method - interpolation method:  'linear' (default), 'cubic', or 'spline'
%
% OUTPUT:
% ------
% f      - (M X 2) matrix of uniformly sampled points on the curve
%
% SEE ALSO:
% --------
% cset_arcresamp.m
%
% HISTORY:
% -------
% This function is basically equivalent to the old curve_resample.m program, 
% except this one is designed to work with cell arrays.
%
% 2004/12/05 (MCB) - Added code to eliminate redundant poitns which seem to 
%                      cause problems for the interp1 function.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

EPS = 1e-14;
if (nargin < 3)
  method = 'linear';
end
if (nargin < 2)
  ds = 1;
end

x = e(:,1);
y = e(:,2);

d = [0; sqrt((diff(x)).^2 + (diff(y)).^2)];

% Somehow we occassionally get a redundant point which
%  causes problems to interp1.
ind = find(d < EPS);
L = length(ind);
if (L > 1)
  d(ind(2:L)) = [];
  x(ind(2:L)) = [];
  y(ind(2:L)) = [];
end
N = length(x);


s = cumsum(d);
u = (0:ds:s(N))';

ind = find(diff(s) == 0);
if (length(ind) > 0)
  keyboard
end
x2 = interp1(s,x,u,method); % Always returns a column vector
y2 = interp1(s,y,u,method); % Always returns a column vector

f = [x2, y2];
