function r = bbox_test(B1, B2);
%
% BBOX_TEST: r = bbox_test(B1, B2);
%
% INPUT:
% -----
% B1 - (2 X d) axis-aligned bounding box
% B2 - (2 X d) axis-aligned bounding box
%
%       For both the top row is the minimum along each dimension and bottom row is maximum
%
% OUTPUT:
% ------
% r  - 0 (no intersection) or 1 (intersection)
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------


[n1,d1] = size(B1);
[n2,d2] = size(B2);

% Error checking
if (n1 ~= 2)
  fprintf(1, 'ERROR (bbox_test): B1 must have two rows\n');
  r = [];
  return;
end
if (n2 ~= 2)
  fprintf(1, 'ERROR (bbox_test): B2 must have two rows\n');
  r = [];
  return;
end
if (d1 ~= d2)
  fprintf(1, 'ERROR (bbox_test): B1 and B2 must have same number of columns\n');
  r = [];
  return;
end

r = 1;
for d = 1:d1
  if ( (B1(1,d) > B2(2,d)) | (B1(2,d) < B2(1,d)) )
    r = 0;
    break;
  end
end