function P = bitmap_contours(I);
%
% BITMAP_CONTOURS: P = bitmap_contours(I);
%
% Detect edges in a binary image with one object using contour following.
%
% INPUT:
% -----
% I      - binary image (0 or 1)
%
% OUTPUT:
% ------
% P      - N X 2 array of points describing contour around the one object.
%
% HISTORY:
% -------
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

[ir, ic] = size(I);

% Create dual image to represent "on" vertices. If a pixel is on,
%   then its four vertices are considered to be on. Note that integer-valued
%   coordinates in the dual image correspond to half-pixel coordinates in
%   the original image.
dr = ir+1;
dc = ic+1;
D = zeros(dr, dc);
[i,j] = find(I);
for k = 1:length(i)
  D(i(k), j(k)) = 1;
  D(i(k), j(k)+1) = 1;
  D(i(k)+1, j(k)) = 1;
  D(i(k)+1, j(k)+1) = 1;  
end

% Eliminate landlocked vertices
LL = zeros(dr, dc);
[i,j] = find(D);
ll = [-1,0; -1,-1;0,-1;0,0];
for k = 1:length(i)
  landlocked = 1;
  for m = 1:size(ll,1)
  ii = i(k)+ll(m,1);
    jj = j(k)+ll(m,2);    
    if ((ii >=1) & (ii <= ir) & (jj >= 1) & (jj <= ic))
      if (I(ii,jj) == 0)
	landlocked = 0;
      end
    else
      landlocked = 0; % image border pixels not landlocked
    end
  end
  LL(i(k), j(k)) = landlocked;
end
D = D.*(~LL);

bbox  = [min(i), min(j); max(i), max(j)];

% Find first point
i0 = bbox(1,1);
j0 = min(find(D(i0,:))); % leftmost element in topmost non-empty row
prev_dir = 1;

% indexed by (prev_dir, preferrence)
di = [-1, 0, 1; 0, 1, 0; 1, 0, -1; 0, -1, 0];
dj = [0, 1, 0; 1, 0, -1; 0, -1, 0; -1, 0, 1];
new_dir = [4, 1, 2; 1, 2, 3; 2, 3, 4; 3, 4, 1];
checki = [-1, 0; 0, 0; 0, -1; -1, -1];
checkj = [0, 0; 0, -1; -1, -1; -1, 0];

P = [j0, i0]; % record contour points in (x,y) format; correct for dual offset later
pr = 1;  
done = 0;
while (~done)
  % Check for potential continuations
  found = 0;
  for k = 1:3
    ii = P(pr,2) + di(prev_dir, k);
    jj = P(pr,1) + dj(prev_dir, k);
    if ((ii >= 1) & (ii <= dr) & (jj >= 1) & (jj <= dc))
      if (D(ii,jj) == 1)
	if ((k == 1) | (k == 2))
	  ic = P(pr,2) + checki(prev_dir,k);
	  jc = P(pr,1) + checkj(prev_dir,k);	  
	  if (I(ic,jc) == 1)
	    found = 1;
	  end
	else
	  found = 1;
	end
	if (found == 1)
	  % Found best continuation
  	  P = [P; jj, ii];
	  pr = pr+1;
	  prev_dir = new_dir(prev_dir, k);
	  if ((ii == i0) & (jj == j0))
	    done = 1;
	  end
	  break;
	end
      end
    end
  end
  if (~found)
    fprintf(1, 'ERROR (bitmap_contours): continuation not found\n');
    keyboard
  end
end
P = P - ones(pr,1)*[0.5, 0.5]; % Correct for dual offset
  
