function B = cell_objects(F, L, num_objects)
% CELL_OBJECTS: B = cell _objects(F, L, num_objects);
%
% Produce a cell array B in which each cell contains a set of contours in 3D
%   that are part of a single object. 
%
% INPUT:
% -----
% F           - (n_levels X 1) cell array; cell l contains the set of contours detected at stack level l.
% L           - (n_levels X 1) cell array; output from zlink; contours are now assigned object id numbers.
% num_objects - scalar; number of objects identified in zlink.
%
% OUTPUT:
% ------
% B          - (num_objects X 1) cell array; cell i contains the set of contours associated
%               with object id i.
%
% SEE ALSO:
% --------
% zlink.m
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

B = cell(num_objects,1);

% Determine how many contours in each object
n_levels = size(F,1);
cnt = zeros(num_objects, 1);
for l = 1:n_levels
  ids = L{l,1};
  cnt(ids) = cnt(ids)+1;
end

% Go through and put contours into the correct place
for k = 1:num_objects
  Ck = cell(cnt(k), 1);  % contours for object k
  
  n = 0;
  for l = 1:n_levels
    S2D = F{l,1};
    ids = L{l,1};
    u = find(ids == k);
    for j = 1:length(u)
      n = n+1;
      tmp = S2D{u(j), 1};      
      Ck{n,1} = [tmp, l*ones(size(tmp,1),1)]; 
    end
  end
  B{k,1} = Ck;
end
