function TE_master = combined_te(TLL_master, E_master)
%
% COMBINED_TE: TE_master = combined_te(TLL_master, E_master);
%
% Match nucleus locations (derived from hand marked disks?) with ellipses derived
% based on automatic segmentation. 
%
% INPUT:
% -----
% TLL_master -
% E_master -
%
% OUTPUT:
% ------
% TE_master -
%
% NOTE:
% ----
% Use the following to plot the ellipses for frame t =1
%
% >> ind = find(TE_master(:,1) == 1);
% >> plot_ellipse_many(TE_master(ind,6:10), 2, 'r', 2);
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% distmat.m
% bipartite_mutual_nn.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

tlldir = '/proj/og1/biology/aroeder/data/flower_5/correspondences/';
if (nargin < 2)
  E_junk = load('/proj/og1/biology/aroeder/B_master.mat');
  E_master = E_junk(1,1).B_master;
end
if (nargin < 1)
  TLL_junk = load([tlldir, 'TLL_master.mat']);
  T_master = TLL_junk(1,1).T_master;
  LL_master = TLL_junk(1,1).LL_master;  
end

[tr, tc] = size(T_master);
[er, ec] = size(E_master);
if (tc ~= 4)
  fprintf(1, 'ERROR (combined_te): dimension error\n');
  return
end
TE_master = [T_master, NaN * ones(tr, 6)];

thr = 1e-04;
for i=1:tr
  tgt = LL_master{i,1};
  skip = 0;
  if (length(tgt) >= 1)
    if (strcmp(tgt(1:1), '-') == 1) % no matching ellipses for negative labels
      skip = 1;
    end
  else
    skip = 1;
  end

  if (skip == 0)
    t = T_master(i,1);
    E = E_master{t,1};
    D = distmat(T_master(i,2:3), E(:,2:3));
    m = bipartite_mutual_nn(D);
    if ( (size(m,1) > 0) & (D(m(1,1), m(1,2)) < thr) )
      TE_master(i,5:10) = E(m(1,2),:);
    end
  end
end

keyboard
