function fname = construct_fname(ibase, isuff, f, fwidth)
%
% CONSTRUCT_FNAME: fname = construct_fname(ibase, isuff, f, fwidth);
%
% Construct filenames from a base, suffix, and frame number. Both fixed-width
% frame number formats (e.g., img012.jpg) and natrual-width formats (e.g., img12.jpg)
% are supported via the fwidth argument.
%
% INPUT:
% -----
% ibase   - base filename (everything before the frame number including the path)
% isuff   - suffix (everything after the frame number including the extension)
% f       - frame number
% fwidth  - width of frame number for fixed-width formats (e.g., img0001.jpg, img0012.jpg) 
%             or 0 for natural-width formats (e.g., img1.jpg, img12.jpg)
%
% OUTPUT:
% ------
% fname   - filename for frame f
%
% EXAMPLE:
% -------
% construct_fname('/home/burl/image_', '.tif', 12, 3) -> '/home/burl/image_012.tif'
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (fwidth > 0)
  fmt = ['%.',int2str(fwidth),'d'];
  ff = sprintf(fmt, f);
else
  ff = int2str(f);  
end
fname = [ibase, ff, isuff];