function [arg1, arg2, arg3] = count_lines(fname, cc);
%
% COUNT_LINES: [n_lines]                 = count_lines(fname);
%              [n_lines, n_comments]     = count_lines(fname, cc);
%              [fp, n_lines]             = count_lines(fname);
%              [fp, n_lines, n_comments] = count_lines(fname, cc);
%
% There are four basic forms in which this program can be invoked.
% 1) Return number of lines in the file. Close the file.
% 2) Return number of lines excluding comment lines. Also return a
%    count of the number of comment lines. The comment lines are
%    those which begin with the characters specified by the input
%    arg cc. Close the file.
% 3) Return file pointer and number of lines. The file is rewound and
%    left open upon return.
% 4) Return file pointer, number of regular lines, and number of
%    comment lines. The file is rewound and left open upon return.
%
% HISTORY:
% =======
% MOD: 20060726 (MCB) - replaced calls to myfgetl with fgetl. (A long time
%    ago there was a bug with Matlab's fgetl, but I think it must be fixed by now.)
%
% MOD: 19991005 (MCB) - Noticed a problem reading some Cyrano electronic
%    nose files supplied by Adam Matzger (count_lines was returning
%    an incorrect line count so I changed the loops from OLD to NEW
%    in case 1 and case 3.
%
%  %% OLD %%
%  while (myfgetl(fp) ~= -1)
%    nl = nl+1;
%  end
%
%  %% NEW %%
%  while (1)
%    buffer = myfgetl(fp);
%    if (buffer == -1)
%      break;
%    end
%    nl = nl+1;
%  end
%
% MOD: 19970917 (MCB) - Changed variable "case" to "cse" because case is
%    apparently a reserved word in Matlab 5.0.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if ((nargin == 1) & (nargout == 1))
  cse = 1;
  nl = 0;
  fp = fopen(fname, 'r');
  if (fp < 0)
    error(['ERROR: Unable to open file: ', fname]);
  end

  while (1)
    buffer = fgetl(fp);
    if (buffer == -1)
      break;
    end
    nl = nl+1;
  end  

  arg1 = nl;
  fclose(fp);
%.................................................................
elseif ((nargin == 2) & (nargout == 2))
  cse = 2;
  nl = 0;
  nc = 0;
  fp = fopen(fname, 'r');
  if (fp < 0)
    error(['ERROR: Unable to open file: ', fname]);
  end
 
  buffer = fgetl(fp);
  while (buffer ~= -1)
    if (buffer(1) == cc)
      nc = nc+1;
    else
      nl = nl+1;
    end
    buffer = fgetl(fp);
  end

  arg1 = nl;
  arg2 = nc;
  fclose(fp);
%.................................................................
elseif ((nargin == 1) & (nargout == 2))
  cse = 3;  
  nl = 0;
  fp = fopen(fname, 'r');
  if (fp < 0)
    error(['ERROR: Unable to open file: ', fname]);
  end

%  while (fgetl(fp) ~= -1)
%    nl = nl+1;
%  end
  while (1)
    buffer = fgetl(fp);
    if (buffer == -1)
      break;
    end
    nl = nl+1;
  end
  

  arg1 = fp;
  arg2 = nl;

  % Rewind the file
  fseek(fp, 0, -1);
%.................................................................
elseif ((nargin == 2) & (nargout == 3))
  cse = 4;
  nl = 0;
  nc = 0;
  fp = fopen(fname, 'r');
  if (fp < 0)
    error(['ERROR: Unable to open file: ', fname]);
  end
 
  buffer = fgetl(fp);
  while (buffer ~= -1)
    if (buffer(1) == cc)
      nc = nc+1;
    else
      nl = nl+1;
    end
    buffer = fgetl(fp);
  end

  arg1 = fp;
  arg2 = nl;
  arg3 = nc;

  % Rewind the file
  fseek(fp, 0, -1);
%.................................................................
else
  error('ERROR: Illegal combination of input and output args');
end
