function I = cset_to_bitmap(ir, ic, Cset);
%
% CSET_TO_BITMAP: B = cset_to_bitmap(ir, ic, Cset);
%
% Convert vector contours into pixel contours using Bezier line idea.
%
% INPUT:
% -----
% ir     - scalar, rows in output image
% ic     - scalar, cols in output image
% Cset   - (N X 1) cell array; each cell has an (? X 2) matrix in which
%           the rows of the matrix contain (x,y) points along the n-th curve
%
% OUTPUT:
% ------
% I      - (ir X ic) binary image
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

N = size(Cset,1); % number of curves in the set
I = zeros(ir, ic);

for n = 1:N
  C = Cset{n,1};
  cr = size(C,1);
  for p = 1:cr-1
    x0 = round(C(p,1));
    y0 = round(C(p,2));

    x1 = round(C(p+1,1));
    y1 = round(C(p+1,2));
    
    if (abs(y1-y0) > abs(x1-x0))
      steep = 1;
    else
      steep = 0;
    end
    
    if (steep == 1)
      % swap x0 <-> y0
      h = x0;
      x0 = y0;
      y0 = h;
      % swap x1 <-> y1
      h = x1;
      x1 = y1;
      y1 = h;
    end
    if (x0 > x1)
      % swap x0 <-> x1
      h = x0;
      x0 = x1;
      x1 = h;
      % swap y0 <->y1
      h = y0;
      y0 = y1;
      y1 = h;
    end
    
    delta_x = x1-x0;
    delta_y = abs(y1-y0);
    
    if (y0 < y1)
      ystep = 1;
    else
      ystep = -1;
    end
      
    e = 0;
    y = y0;
    for x = x0:x1
      if (steep == 1)
	if ((x >= 1) & (x <= ir) & (y >= 1) & (y <= ic))
	  I(x,y) = 1;
	end
      else
	if ((y >= 1) & (y <= ir) & (x >= 1) & ( x <= ic))
	  I(y,x) = 1;
	end
      end
      e = e + delta_y;
      if (2*e >= delta_x)
	y = y + ystep;
	e = e - delta_x;
      end
    end
  end
end


