function display_polyhedrons(P, C)
%
% DISPLAY_POLYHEDRONS: display_polyhedrons(P, C);
% 
% Create a rendering of a set of polyhedrons.
%
% INPUT:
% -----
% P - (N x 1) cell array, where N is the number of polyhedrons (biological cells)
% C - (N x 3) array of colors [optional]; colors are randomly assigned if C is omitted
%
% OUTPUT:
% ------
% New figure with a colored rendering of the polyhedrons
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% randcol.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 2)
  C = randcol(size(P,1), 0.3);
end

figure;
for n=size(P,1):-1:1
  F = P{n,1};
  for f = 1:size(F,1)
    V = F{f,1};
    fill3(V(:,1), V(:,2), V(:,3), C(n,:));
    hon;
  end
end