function display_triangulated(V, T, C, L, oid)
%
% DISPLAY_TRIANGULATED: display_triangulated(V, T, C, L, oid)
%
% Display triangulated surfaces in current figure window. You can then
% use the rotation widget on the figure window to change viewpoint. With
% large numbers of triangles, don't expect same smoothness and responsiveness 
% as with Amira.
%
% INPUT:
% -----
% V - (nv x 3) matrix of 3D vertices
% T - (nt x 3) matrix of triangles (each row contains 3 indices into V)
%       Note: that the sense of the triangle must be in correct order
%       to insure surface normals are pointing in the right direction
% C - (nt x 3) matrix of RGB colors for each triangle
% L - (nt x 1) matrix with object label for each triangle
% oid - vector with object ids to display; default is to omit this and display all objects
%         (equivalently can specify oid = [] to display all)
% OUTPUT:
% ------
% Display of triangulated surface in current figure window
%
% SEE ALSO:
% --------
% triangulate_cell_objects.m
%
% HISTORY:
% -------
% 20061107 (MCB) - found major bug wrt oid.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 5)
  oid = [];
end

hon;
for q = 1: size(T,1) % walk through triangles
  Lq = L(q,1); % Object label for this triangle
  skipq = 0;
  if (~isempty(oid))
    if (all(Lq ~= oid))
      skipq = 1; % if a display list was supplied, but Lq is not on it, then skip
    end
  end

  if (~skipq)
    P = [V(T(q,1),:); V(T(q,2),:); V(T(q,3),:); V(T(q,1), :)];
    fill3(P(:,1), P(:,2), P(:,3), C(q,:));
  end
end
