function display_voxelized(V, C, oid)
%
% DISPLAY_VOXELIZED: display_voxelized(V, C, oid)
%
% Display voxelized object in current figure window. You can then
% use the rotation widget on the figure window to change viewpoint. 
%
% INPUT:
% -----
% V - (nx X ny X nz) cube; each voxel in cube contains an object id number (or 0)
% C - (nt x 3) matrix of RGB colors for each object ID
% oid - vector with object ids to display; default is to omit this and display all objects
%         (equivalently can specify oid = [] to display all)
% OUTPUT:
% ------
% Display of voxlized object in current figure window
%
% SEE ALSO:
% --------
% voxelize_polyhedrons.m
%
% HISTORY:
% -------
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% hon.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
s = 0.50;
if (nargin < 3)
  oid = [];
end

hon;
[nx, ny, nz] = size(V);
for i=1:nx
  for j=1:ny
    for k=1:nz
      skip = 0;
      L = V(i,j,k);
      if (L ~= 0)
        if (~isempty(oid))
	  if (all(L ~= oid))
	    skip = 1; % a display list was supplied but L is not on it, so skip
	  end
        end	  

	if (~skip)
          P1 = [i-s, j-s, k-s; i-s, j+s, k-s; i-s, j+s, k+s; i-s, j-s,k+s];
          P2 = [i+s, j-s, k-s; i+s, j+s, k-s; i+s, j+s, k+s; i+s, j-s,k+s];
          P3 = [i-s, j-s, k-s; i-s, j+s, k-s; i+s, j+s, k-s; i+s, j-s,k-s];
          P4 = [i-s, j-s, k+s; i-s, j+s, k+s; i+s, j+s, k+s; i+s, j-s,k+s];	  
          P5 = [i-s, j+s, k-s; i+s, j+s, k-s; i+s, j+s, k+s; i-s, j+s,k+s];
          P6 = [i-s, j-s, k-s; i+s, j-s, k-s; i+s, j-s, k+s; i-s, j-s,k+s];	  
          fill3(P1(:,1), P1(:,2), P1(:,3), C(L,:));
          fill3(P2(:,1), P2(:,2), P2(:,3), C(L,:));
          fill3(P3(:,1), P3(:,2), P3(:,3), C(L,:));
          fill3(P4(:,1), P4(:,2), P4(:,3), C(L,:));
          fill3(P5(:,1), P5(:,2), P5(:,3), C(L,:));
          fill3(P6(:,1), P6(:,2), P6(:,3), C(L,:));	  
	end
      end
    end
  end
end