function D = distmat(A,B)
% DISTMAT: D = distmat(A, B);
%
% Compute matrix of pairwise (Euclidean) distances between two sets of
% d-dimensional points.
%
% INPUT:
% -----
% A - (N x d) matrix; each row is a data point in d-dimensions
% B - (M x d) matrix; each row is a data point in d-dimensions
%
% OUTPUT:
% ------
% D - (N X M ) matrix of Euclidean distances between A(i,:) and B(j,:)
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
if (nargin < 2)
  B = A;
end

[ar, ac] = size(A);
[br, bc] = size(B);

if (ac ~= bc)
  fprintf(1, 'ERROR (distmat): number of cols in A and B must match!\n');
  D = [];
  return
end

D = zeros(ar, br);
for i = 1:ar
  for j = 1:br
    D(i,j) = sqrt(sum( (A(i,:) - B(j,:)).^2));   
  end
end
