function R_master = endoreduplication(icell)
%
% ENDOREDUPLICATION: endoreduplication(icell);
%
% Study endoreduplication statistics on a set of images named in the.
%   cell array icell.
%
% INPUT:
% -----
% icell - cell array with image names (including paths); see load_lines.m
%
% OUTPUT:
% ------
% R_master - (M x 5) matrix where M is total numer of segmented objects
%              in all the images. First column is major radius, second column 
%              is minor radius.
%
% NOTE: 
% ----
% Looks like this was an early prototype for doing nucleus segmentation in projection images
% and looking at ellipse shape/size parameters. The segmentation part is superseded by
% sepal_nuclei.m. The code below that uses symeig2 is superseded by icluster_ellipse_params.m
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% median_filter.m
% icluster.m
% icluster_moments.m
% symeig2.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

thr = 40;
N = size(icell,1);
R_master = [];
for n = 1:N
  I = imread(icell{n,1});
  J = squeeze(I(:,:,2)); % nuclei are in the green channel
  Y = median_filter(J, 5);
  [L, nobj] = icluster((Y > thr), ones(2,1));
  A = icluster_moments(L, nobj);
  r = zeros(nobj,5);
  for i=1:nobj
    [eve, eva] = symeig2([A(i,4), A(i,5); A(i,5), A(i,6)]);
    r(i,:) = [A(i,2), A(i,3), sqrt(diag(eva))', atan2(eve(2,2), eve(1,2))];
  end
  R_master = [R_master; r];
  keyboard
end
