function Rn = erode_polyhedrons(Pn, epsilon)
%
% ERODE_POLYHEDRONS: R = erode_polyhedrons(Pn, epsilon);
%
% Given a set of polyhedrons in normals form, erode each polyhedron
% by moving cell walls in by epsilon.
%
% INPUT:
% -----
% Pn      - (n_cells X 1) set of polyhedrons in normals form
% epsilon - scalar; amount of erosin to apply 
%
% OUTPUT:
% ------
% Rn     - (n_cells X 1) set of polyhedrons in normals form
%
% SEE ALSO:
% --------
% normals_to_facets.m
% facets_to_normals.m
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

N = size(Pn,1);
Rn = cell(N,1);
for n = 1:N
  A = Pn{n,1};
  A(:,4) = A(:,4) - epsilon;
  Rn{n,1} = A;
end