function A = estimate_affine_transformation(X, Y)
%
% ESTIMATE_AFFINE_TRANSFORMATION: A = estimate_affine_transformation(X, Y);
%
% Determine the best affine transformation that maps points in X (source) to 
%   Y (target). Result is a () X () matrix.
%
% INPUT: 
% -----
% X          - (N x ds) matrix; each row is a point
% Y          - (N x dt) matrix; each row is a point
%
% OUTPUT:
% ------
% A          - affine transformation matrix (dt X (ds+1))
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

[N, ds] = size(X);
[N2, dt] = size(Y);
if (N2 ~= N)
  fprintf(1, 'ERROR (estimate_affine_transformation): rows in X and Y must match\n');
  A = [];
  return
end

% Make sure we have enough constraints
if ((ds == 2) & (dt == 2) & (N >= 3))
  err_flag = 0;
elseif ((ds == 3) & (dt == 2) & (N >= 4))
  err_flag = 0;
elseif ((ds == 3) & (dt == 3) & (N >= 4))
  err_flag = 0;
else
  err_flag = 1;
end

%---------------------------------------------------------------------------------------------
% ERROR CHECK BEFORE RETURN
if (err_flag == 0)
  G = [X, ones(N,1)]; % (N x (ds+1)) - add on a column of ones
  A  = (pinv(G)*Y)';  % pinvG is ((ds+1) x N) and Y is (N x dt), so A will be (dt X (ds+1))
else
  fprintf(1, 'ERROR (estimate_affine_transformation): failed\n');
  A = [];
end
  
return
