function H = find_dependencies(fname)
%
% FIND_DEPENDENCIES: H = find_dependencies(fname);
%
% INPUT:
% -----
% fname - filename
%
% OUTPUT:
% ------
% H     - cell array with names of dependencies
%
% NOTE:
% ----
% Dependencies are identified from #include directives (in .c, .h, .cpp, and .hpp files) or
% by blocks such as the following in (.c, .h, .cpp, or .hpp) files:
%
% // BEGIN CDS DEPENDENCIES
% // burl.h
% // matrix.h
% // END CDS DEPENEDENCIES
%
% or by blocks as shown below for .m files:
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% count_lines.m
% tokenizer.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

[fp, n_lines] = count_lines(fname);

H = cell(n_lines, 1); % overkill

in_block = 0;
h = 0;
for n = 1:n_lines
  line = fgetl(fp);
  
  if (in_block == 0)
    % See if line starts a block
    if (strcmp(line, '// BEGIN CDS DEPENDENCIES') == 1)
      in_block = 1;
    elseif  (strcmp(line, '/* BEGIN CDS DEPENDENCIES */') == 1)
      in_block = 1;
    elseif (strcmp(line, '% BEGIN CDS DEPENDENCIES') == 1)      
      in_block = 1;
    else
      % See if this is a #include directive
     [s, e] = tokenizer(line, []);
     if (length(s) == 2)
       if (strcmp(line(s(1):e(1)), '#include') == 1)
	 if (e(2)-s(2) >= 2)
	   if ((line(s(2)) == '"') & (line(e(2)) == '"')) % ignore things in angle brackets
	     h = h+1;
	     H{h,1} = line(s(2)+1:e(2)-1);
	   end
	 end
       end
     end
    end
  elseif (in_block == 1)
    % See if line ends a block
    if (strcmp(line, '// END CDS DEPENDENCIES') == 1)
      in_block = 0;
    elseif  (strcmp(line, '/* END CDS DEPENDENCIES */') == 1)
      in_block = 0;
    elseif  (strcmp(line, '% END CDS DEPENDENCIES') == 1)      
      in_block = 0;
    else
      % We have a dependence inside a block
      [s, e] = tokenizer(line, []);
      if (length(s) >= 2)
	h = h+1;
	H{h,1} = line(s(2):e(2));
      end
    end
  end
end

fclose(fp);

% Compress H
HH = cell(h,1);
for i=1:h
  HH{i,1} = H{i,1};
end
H = HH;