function R_master = fix_hand_truth()
%
% FIX_HAND_TRUTH: R_master = fix_hand_truth()
%
% Fix hand-labeled ground truth from images provided by Adrienne Roeder.
%
% OUTPUT:
% ------
% R_master      - (N x 4) matrix with hand truth information for each nucleus that
%                   appears any time during the duration of the 4D stack sequence
%
%                   col1 - timepoint
%                   col2 - x centroid
%                   col3 - y centroid
%                   col4 - nucleus id
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% hon.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

idir = '/proj/og1/biology/aroeder/data/flower_5/hand_tracked/dots_only/';
ibase = '5_';
isuff = 'zdots.tif';

%R_master = load([idir, 'ground_truth.txt']);
%R_master = load([idir, 'ground_truth_fixed.txt']);
%R_master = load([idir, 'ground_truth_fixed3.txt']);
%R_master = load([idir, 'ground_truth_fixed4.txt']);
R_master = load([idir, 'ground_truth_fixed5.txt']);
mfd = []; % Rows of R_master that are marked for deletion

for n = 1:17
  if ((n ~= 10) & (n ~= 16))
    iname = construct_fname([idir, ibase], isuff, n, 0);
    RGB = imread(iname);
    figure; image(RGB); hon;

    ind = find(R_master(:,1) == n); % which rows in R_master pertain to this image
    xyl = R_master(ind, 2:4);
    L = length(ind);
    h = zeros(L,1); % text handles
    for i = 1:L
      h(i) = text(xyl(i, 1), xyl(i,2), int2str(xyl(i,3)), 'Fontsize', 12, 'Color', 'k');
    end

    % PLOT LINES BETWEEN CELLS WITH SAME LABEL
    for i=1:L-1
      for j=i+1:L
	if (xyl(i,3) == xyl(j,3))
	  plot([xyl(i,1), xyl(j,1)], [xyl(i,2), xyl(j,2)], 'r', 'Linewidth', 2);
	end
      end
    end
    
    % LABELING AJUSTMENT LOOP
    done = 0;
    while (~done)
      [u, v, button] = ginput(1);
      if (button == 3)
	% Quit
	keyboard
	done = 1;
      elseif (button == 2)
	% Create a new disk
	new_label = input('Create new label: ');
	if (new_label ~= 0)
  	  xyl = [xyl; [u, v, new_label]]; 
	  ind = [ind; size(R_master,1)+1];
          R_master = [R_master; [n, u, v, new_label]];
	  plot(u, v, 'ro', 'Markersize', 12);
          hh = text(u, v, int2str(new_label), 'Fontsize', 12, 'Color', 'k');		  
	  h = [h; hh];
	  L = L+1;
        end
      else
	% Modify or delete label of an existing disk
	new_label = input('Enter new label (or 0 to delete): ');
	
	% Find closest disk to mouse click
        d = distmat([u,v], xyl(:,1:2));
	[dmin, imin] = min(d); % Find closest

	if (new_label ~= 0)
	  % Change existing label of closest disk
	  xyl(imin,3) = new_label;
	  R_master(ind(imin), 4) = new_label;
	  delete(h(imin));
          h(imin) = text(xyl(imin, 1), xyl(imin,2), int2str(xyl(imin,3)), 'Fontsize', 12, 'Color', 'k');	
	else
	  % Delete existing label of closest disk
	  delete(h(imin));
	  mfd = [mfd; ind(imin)]; % mark row of R_master for deletion
	  xyl(imin,:) = [];
	  h(imin) = [];
	  ind(imin) = [];
	  L = L-1;
	end
      end
    end
  end
end
if (~isempty(mfd))
  R_master(mfd,:) = [];
end
keyboard
