function  flower_5_area_vs_time(TE_master, LL_master, C_master)
%
% FLOWER_5_AREA_VS_TIME: flower_5_area_vs_time(TE_master, LL_master, C_master);
%
% Construct a plot showing progression of nucleus area vs time for each nucleus present
% in the initial frame (t0 = 1) based on flower_5 data.
%
% INPUT:
% -----
% TE_master - (n x 10) matrix; col1 = time, col2 = x, col3 = y, col4 = z, col5-col10 = ellipse moments
% LL_master - (n x 1) cell array with lineage (tree) labels
% C_master  - (n_ancestors X 3) color matrix
%
% OUTPUT:
% ------
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% hon.m
% lineage_label_to_vector.m
% plot_progeny.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

figure; hon;
t0 = 1;
ind = find(TE_master(:,1) == t0); % indices of objects for frame t=t0
for k = 1:length(ind)
  tgt = LL_master{ind(k),1}; % lineage label of k-th object for frame t=t0
  skip = 0;
  if (length(tgt) >= 1)
    if (strcmp(tgt,'0') == 1)
      skip = 1;
    elseif (strcmp(tgt(1:1), '-') == 1)
      skip = 1;
    end
  else
    skip = 1;
  end
  
  if (~skip)
    v = lineage_label_to_vector(tgt);
    g = length(v);
    if (g >= 1)
      ancestor = v(1,1);
      plot_progeny(t0, tgt, C_master(ancestor,:), TE_master, LL_master);
    end
  end
end
