function flower_5_flow(f1, f2)
%
% FLOWER_5_FLOW: flower_5_flow(f1, f2);
%
% Make vector plot showing motion of nuclei from frame f1 to frame f2. Vectors seem to be
% color-coded based on number of divisions.
%
% INPUT:
% -----
% f1 - start frame
% f2 - end frame
%
% OUTPUT:
% ------
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% hon.m
% bipartite_mutual_nn.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
idir = '/proj/og1/biology/aroeder/data/flower_5/hand_tracked/dots_only/';
R_master = load([idir, 'ground_truth_fixed5.txt']);
C_master = load([idir, 'C_master_fixed5.txt']);

ind1 = find(R_master(:,1) == f1);
ind2 = find(R_master(:,1) == f2);

n1 = length(ind1);
n2 = length(ind2);

xyl1 = R_master(ind1, 2:4);
xyl2 = R_master(ind2, 2:4);

%keyboard
mu1 = mean(xyl1(:,1:2));
mu2 = mean(xyl2(:,1:2));
delta = mu2 - mu1;
delta = [0, 0];

figure;
%keyboard

for i = 1:n1
%  plot(xyl1(i,1), xyl1(i,2), 'o', 'Markersize', 12, 'Color', C_master(xyl1(i,3),:)/255, 'Linewidth', 2);
  plot(xyl1(i,1), xyl1(i,2), '.', 'Markersize', 12, 'Color', C_master(xyl1(i,3),:)/255, 'Linewidth', 2);  
  hon
end

for i = 1:n2
%  plot(xyl2(i,1)-delta(1), xyl2(i,2)-delta(2), '^', 'Markersize', 12, 'Color', C_master(xyl2(i,3),:)/255, 'Linewidth', 2);
  plot(xyl2(i,1)-delta(1), xyl2(i,2)-delta(2), '^', 'Markersize', 6, 'Color', C_master(xyl2(i,3),:)/255, 'Linewidth', 2);  
  hon
end

rho = bipartite_mutual_nn(xyl1(:,3), xyl2(:,3));
m = size(rho,1);
cols = 'rgbcmyk';
for k=1:m
  i = rho(k,1);
  j = rho(k,2);
  n = length(find(rho(:,1) == i));
  plot([xyl1(i,1), xyl2(j,1)-delta(1)], [xyl1(i,2), xyl2(j,2)-delta(2)], cols(n:n), 'Linewidth', 2);
end

