function flower_5_ground_truth()
%
% FLOWER_5_GROUND_TRUTH: flower_5_ground_truth();
%
% Convert the ground truth (labels and positions) from Adrienne's hand labeling 
%   of the flower_5 sequence to the 20071029 stacks.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% hon.m
% estimate_affine_transformation.m
% construct_fname.m
% fig.m
% plot_ellipse_many.m
% bipartite_mutual_nn.m
% retrieve_z.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
EPS = 1e-7;

tdir = '/proj/og1/biology/aroeder/data/flower_5/hand_tracked/dots_only/';
ddir = '/proj/og1/biology/aroeder/data/flower_5/hand_tracked/dots_overlaid/';
pdir = '/proj/og1/biology/aroeder/data/flower_5/projections/20071029/';

GT = load([tdir, 'ground_truth_fixed6.txt']);
C  = load([tdir, 'C_master_fixed5.txt']);
L  = load([tdir, 'L_master.mat']);
Bjunk = load('/proj/og1/biology/aroeder/B_master.mat');
B_master = Bjunk(1,1).B_master;
lineage_labels = L(1,1).L_master;

for t = 17:17
  dname = construct_fname([ddir, '5_'], '.tif', t, 0);
  pname = construct_fname([pdir, 't'], '_proj.tif', t, 0);      
  zname = construct_fname([pdir, 't'], '_zmax.tif', t, 0);            
  
  D = imread(dname);
  P = imread(pname);
  Z = imread(zname);
  
  ind = find(GT(:,1) == t);
  
  % Display color image with Adriennes dots overlaid  
  figure;
  title(int2str(t), 'Fontsize', 18);
  f1 = gcf;
  image(D);
  hon;  
  for i=1:length(ind)
    j = ind(i); 
    text(GT(j,2), GT(j,3), lineage_labels{j,1}, 'Color', 'w', 'Fontsize', 12);
  end

  % Display grayscale image from stack projection
  f2 = fig(rot90(P, 1));
  title(int2str(t), 'Fontsize', 18);  
  hon;
  
  done = 0;
  sl = 30;
  figure(f1);    
  axis([min(GT(ind,2))-sl, max(GT(ind,2))+sl, min(GT(ind,3))-sl, max(GT(ind,3))+sl]);
  fprintf(1, 'Need to manually establish some correspondences\n');
  keyboard
  while (~done)
    % Now we need to manually establish correspondences
    figure(f1);
    xy = ginput;
  
    figure(f2);
    uv = ginput;
  
    if (size(xy,1) == size(uv,1))
      cmd = ['save /proj/og1/biology/aroeder/results/t', int2str(t), '_correspondences.mat uv xy'];
      eval(cmd);
      done = 1;
    else
      fprintf(1, 'You messed up on manual correspondences - need to redo\n');
    end
  end
  
  % Estimate affine transformation
  A = estimate_affine_transformation(uv, xy);
  A= [A; [0,0,1]]; 
  [pr,pc] = size(P);
  R = [0, 1, 0; -1, 0, pc+1; 0, 0, 1]; % take care of the rot90
  AR = A*R
%   % Create warped version of the stack projection image and
%   %   show how the ground truth points fall on there.
%   W = imwarp(I5, AR, size(D5,1), size(D5,2));   
%   fig(W)
%   plot(GT(ind,2), GT(ind,3), 'rx')

  % Stack projection image
  fig(P); hon;
  title(int2str(t), 'Fontsize', 18);  
  
  % Warp the ground truth from dots_overlaid back to the stack projections
  GT_stack = (inv(AR) * [GT(ind,2:3), ones(length(ind),1)]')';
  plot(GT_stack(:,1), GT_stack(:,2), 'cx')
  
  % Add the detected nuclei to the plot
  B = B_master{t,1};
  plot_ellipse_many(B(:,2:6), 2, 'b', 1);  

  % Compute distance matrix between ground truth points and detected nuclei (ellipses)
  er = size(GT_stack,1);
  ec = size(B,1);
  E = zeros(er, ec);
  for i = 1:er
    for j = 1:ec
      mu = [B(j,2); B(j,3)];
      S  = [B(j,4), B(j,5); B(j,5), B(j,6)];
      v  = GT_stack(i,1:2)';
      detS = S(1,1)*S(2,2)-S(1,2)*S(2,1);
      if (abs(detS) > EPS)
	E(i,j) = (v-mu)' * inv(S) * (v-mu);
      else
	E(i,j) = (v-mu)' * (v-mu);
      end
    end
  end
  
  rho = bipartite_mutual_nn(E);

  GT_stack_used = zeros(er,1);
  B_used = zeros(ec,1);
  for k=1:size(rho,1)
    i=rho(k,1);
    j=rho(k,2);
    GT_stack_used(i,1) = 1;
    B_used(j,1) = 1;
    plot([GT_stack(i,1), B(j,2)], [GT_stack(i,2), B(j,3)], 'g'); 
  end  
  
  % Assemble the final truth
  nft = size(rho,1) + sum(GT_stack_used==0) + sum(B_used==0);
  T = zeros(nft,4);
  LL = cell(nft,1);  
  ft = 0;
  for k=1:size(rho,1)
    ft = ft+1;
    i = rho(k,1);
    j = rho(k,2);
    z = retrieve_z(B(j,2), B(j,3), Z, 5);
    T(ft,:)  = [t, B(j,2), B(j,3), z];
    LL{ft,1} = lineage_labels{ind(i),1};
  end
  for i=1:er
    if (GT_stack_used(i,1) == 0)
      ft = ft+1;
      z = retrieve_z(GT_stack(i,1), GT_stack(i,2), Z, 5);      
      T(ft,:) = [t, GT_stack(i,1), GT_stack(i,2), z];
      LL{ft,1} = ['-',lineage_labels{ind(i),1}];
    end
  end
  for j=1:ec
    if (B_used(j,1) == 0)
      ft = ft+1;
      z = retrieve_z(B(j,2), B(j,3), Z, 5);      
      T(ft,:) = [t, B(j,2), B(j,3), z];
      LL{ft,1} = '0';
    end
  end
  cmd = ['save /proj/og1/biology/aroeder/results/TLL', int2str(t), '.mat T LL'];
  eval(cmd);
  keyboard
end

