function  M = flower_5_growth_analysis(T_master, LL_master)
%
% FLOWER_5_GROWTH_ANALYSIS: M = flower_5_growth_analysis(T_master, LL_master);
%
% Estimate 3D growth rates in flower_5 data by estimating affine tranformation and looking
% at singular values of the relevant portion of the transformation matrix.
%
% INPUT:
% -----
% T_master - (n x 4) matrix; col1 = time, col2 = x, col3 = y, col4 = z
% LL_master - (n x 1) cell array with lineage (tree) labels
%
% OUTPUT:
% ------
% M         - (15 X 3)
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% lineage_label_match.m
% estimate_affine_transformation.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

xy_scale = [1.8; 0.9*ones(7,1); 1.27*ones(7,1); 1.8; 2.54];
z_scale  = 2;


tt = [1:9, 11:15,17]';
M = zeros(17,3);
M(1,:) = [1, 1, 1];

for i=1:length(tt)-1
  H1 = diag([xy_scale(tt(i),1),xy_scale(tt(i),1),-z_scale]); %scale to physical units and invert the z values of points
  H2 = diag([xy_scale(tt(i+1),1),xy_scale(tt(i+1),1),-z_scale]); %scale to physical units and invert the z values of points  
  
  
  ind1 = find(T_master(:,1)==tt(i)); 
  ind2 = find(T_master(:,1)==tt(i+1)); 
  
  n1 = length(ind1);
  n2 = length(ind2);
  
  LL1 = cell(n1,1);
  for j = 1:n1
    LL1{j,1} = LL_master{ind1(j,1),1};
  end
  LL2 = cell(n2,1);
  for j = 1:n2
    LL2{j,1} = LL_master{ind2(j,1),1};
  end
  
  C = lineage_label_match(LL1, LL2);
  P1 = T_master(ind1(C(:,1)),2:4)*H1; 
  P2 = T_master(ind2(C(:,2)),2:4)*H2;
  
  A = estimate_affine_transformation(P1, P2);
  [U,S,V] = svd(A(1:3,1:3));
  M(i+1,:) = diag(S);
  
%  Sigma1 = cov(P1); 
%  Sigma2 = cov(P2);
%  
%  [U1,S1,V1] = svd(Sigma1,0);
%  [U2,S2,V2] = svd(Sigma2,0);
%  M(i+1,:) = sqrt(diag(S2)./diag(S1));
end
