function flower_5_lineage()
%
% FLOWER_5_LINEAGE: flower_5_lineage();
%
% Generate lineage labels for the flower_5 data.
%
%
% OUTPUT:
% ------
% L_master - cell array; length is equal to the total number of detected nuclei over
%   whole flower sequence (ignoring the fact that some detections are just repeat viewing
%   of an already seen nucleus). Each cell of L_master will hold a lineage label for the
%   detected nucleus. 
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% hon.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
idir = '/proj/og1/biology/aroeder/data/flower_5/hand_tracked/dots_only/';
R_master = load([idir, 'ground_truth_fixed5.txt']);
%C_master = load([idir, 'C_master_fixed5.txt']);

L_master = cell(size(R_master,1),1);
tmax = max(R_master(:,1));
C = randcol(tmax, 0.3);

omax = max(R_master(:,4));
figure
for oid = 1:omax
  ind = find(R_master(:,4) == oid);
  n_oid = length(ind);
  txy = R_master(ind,1:3);
  L = cell(n_oid, 1);
  for j = 1:n_oid
    L{j,1} = num2str(oid);
  end
  
  plot(txy(:,2), txy(:,3), 'ro');
  hon;
  for i=1:size(txy,1)
    text(txy(i,2), txy(i,3), int2str(txy(i,1)));
  end

  % Determine all the times at which this oid appears
  tt = unique(txy(:,1));
  for k = 1:length(tt)-1
    ind1 = find(txy(:,1) == tt(k));
    ind2 = find(txy(:,1) == tt(k+1));
    n1 = length(ind1);
    n2 = length(ind2);
    
      
    for i=1:n1
      ii = ind1(i);
      for j = 1:n2
	jj = ind2(j);
	
	
	plot([txy(ii,2), txy(jj,2)], [txy(ii,3), txy(jj,3)], 'Linewidth', 2, 'Color', C(tt(k),:));
      end
    end
    
    if ((n1 == 1) & (n2 == 1))
      ii = ind1(1);
      jj = ind2(1);
      L{jj,1} = L{ii,1};
    elseif ((n1 == 1) & (n2 > 1))
      ii = ind1(1);
      for j=1:n2
	jj = ind2(j);
	L{jj,1} = [L{ii,1}, '.', int2str(j)];
      end
    elseif (n1 == n2)
      % generate each of the permutations
      nfac = factorial(n1);
      A = zeros(nfac, n1);
      for g=1:nfac
	done = 0;
	while (~done)
  	  w = randperm(n1);
	  done = 1;
	  for f= 1:g-1
	    if (all(A(f,:) == w))
	      done = 0;
	      break;
	    end
	  end
	end
	
	A(g,:) = w;
      end
 
      % evalaute each of the permutations
      E = zeros(nfac,1);
      for g=1:nfac
	for h=1:n1
	  E(g,1) = E(g,1) + (norm(txy(ind1(h),2:3) - txy(ind2(A(g,h)),2:3)))^2;
	end
      end
      [emin, eind] = min(E);
      w_best = A(eind,:);
      
      for h=1:n1
	L{ind2(w_best(h)),1} = L{ind1(h),1};
      end
    else
      fprintf(1, 'm:n case\n');
      hind = [ind1;ind2]; 
      for hh=1:length(hind)
	vv=hind(hh);
	text(txy(vv,2)+1,txy(vv,3)+1, int2str(vv), 'Color', 'r');
      end
      keyboard
    end
  end
  for h = 1:n_oid
    L_master{ind(h),1} = L{h,1};
  end
    
  junk = ginput;
  keyboard
  hof;
end
keyboard
