function A_master = flower_5_nuclei(thr)
%
% FLOWER_5_NUCLEI: A_master = flower_5_nuclei(thr);
%
% Automatically detect nuclei in Adrienne's flower_5 same_mag_proj images.
%
% INPUT:
% -----
% thr      - [OPTIONAL] (n_images X 1) vector; threshold to use for each image
%
% OUTPUT:
% ------
% A_master - (n_images X 1) cell array; cell i contains the icluster_moments
%              from the nuceli identified in image i.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% sepal_nuclei.m
% construct_fname.m
% icluster_moments.m
% plot_ellipse.m
% hon.m
% fig.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
EPS = 0.001;
n_images = 17;

if (nargin < 1)
  thr = 150 *ones(n_images,1);
end

A_master = cell(n_images,1);
% Construct filenames
icell = cell(n_images, 1);
%idir = '/proj/og1/biology/aroeder/data/flower_5/same_mag_proj/';
idir = '/proj/og1/biology/aroeder/data/flower_5/projections/20071029/';
for i=1:n_images
%  icell{i,1} = construct_fname([idir, '5_'], '.tif', i, 0); 
  icell{i,1} = construct_fname([idir, 't'], '_proj.tif', i, 0); 
end

for i=1:n_images
  fprintf(1,'%d\n', i);
  [Lfinal, C] = sepal_nuclei(icell{i,1}, thr(i));
  A = icluster_moments(Lfinal, max(max(Lfinal)), EPS);
  A_master{i,1} = A;
  I = imread(icell{i,1});
  fig(I); hon;
  title(int2str(i), 'Fontsize', 18);
  for j = 1:size(A,1)
    plot_ellipse(A(j,2), A(j,3), A(j,4), A(j,5), A(j,6), 2, 'b', 1);
  end
  pause(0.2);
end

keyboard
