function flower_5_projections(odir)
%
% FLOWER_5_PROJECTIONS: flower_5_projections(odir)
%
% Create maximum intensity projections for each of the 17 time snapshots of flower_5.
%  Also, record depth (frame number) at which the maximum z-value occurs.
%
% ---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% construct_fname.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

n_times = 17;

% These values were for the original flower_5/amiraprocessed stacks
%f1 = [38; 43; 48; 34; 65; 194; 105; 119; 176; 172; 182; 116; 117; 158; 194; 316; 533];
%iparent = '/proj/og1/biology/aroeder/data/flower_5/amiraprocessed/';

% These values are for the 2007/10/29 stacks
f1 = [57; 66; 66; 34; 59; 123; 105; 103; 124; 146; 134; 97; 117; 135; 149; 224; 310];
iparent = '/proj/og1/biology/aroeder/data/flower_5/stacks/';

isuff = '.tif';

for t = 1:n_times
  fprintf(1, '%d\n', t);
  for f = 0:f1(t)
    ibase = [iparent, 't', int2str(t), '/5_', int2str(t), '.'];
    iname = construct_fname(ibase, isuff, f, 4);
    I = imread(iname);
    if (f == 0)
      Imax = I;
      Zmax = zeros(size(I,1), size(I,2));
    else
      ind = find(I > Imax);
      if (~isempty(ind))
	Zmax(ind) = f * ones(length(ind),1);
      end
      Imax = max(Imax, I);
    end
  end
  oname = [odir, 't', int2str(t), '_proj.tif'];
  imwrite(Imax, oname, 'tif');
  zname = [odir, 't', int2str(t), '_zmax.tif'];
  imwrite(Zmax/255, zname, 'tif');
  
%  keyboard
end
