function flower_6_area_vs_time
%
% FLOWER_6_AREA_VS_TIME: flower_6_area_vs_time
%
% Plot nucleus area vs time for a half dozen giant cells and for another cell (or cells?)
% that is dividing. 
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

jnk = load('/proj/og1/biology/aroeder/data/flower_6/hand_tracked/dots_overlaid_lilac/boundaries_lineage_timekeyed.mat');

T  = jnk.T;
LL = jnk.LL;
BB = jnk.BB;
N = size(T,1);

% Calculate areas
A = zeros(N,1);
for n = 1:N
  B = BB{n,1};
  if (~isempty(B))
    M = polygon_mask([1024,1024], B(:,1), B(:,2));
    A(n,1) = sum(sum(M));
  else
    A(n,1) = NaN;
  end
end

t0 = 1;
t1 = 7;

ind = find(T==t1);

L = length(ind);
C = 'rgbcmyk';

figure; hon;
for l=1:L
  G = [];
  j = ind(l);
  for t = t0:t1
    I = lineage_label_info(t, LL{j,1}, T, LL, 0);
    D1 = I{1,1}; % ancestors of LL{j,1};
    D2 = I{2,1}; % direct parent of LL{j,1}
    D3 = I{3,1}; % LL{j,1} itself;
    D = [D1; D2; D3];
    if (~isempty(D))
      G = [G; [t, A(D,1)]];
    end
  end
  v = lineage_label_to_vector(LL{j,1});
  plot(G(:,1), G(:,2), 'Color', C(v(1,1):v(1,1)), 'Linewidth', 2);
end

xlabel('t (12 hour tics)', 'Fontsize', 18);
ylabel('area (pixels)', 'Fontsize', 18);
title('Flower 6:Nucleus Area vs. Time', 'Fontsize', 18);
gron;
