function S = floyd(A)
%
% FLOYD: S = floyd(A);
%
% Given an adjacency matrix A for some graph, compute the shortest path between
%   all pairs of nodes in the graph.
%
% INPUT:
% -----
% A  - (N x N) binary matrix; A(i,j) = 1 if there is an edge from node i to node j
%
% OUTPUT:
% ------
% S  - (N x N) matrix with S(i,j) = shortest path distance from node i to node j
%        (or inifinity if no path exists).
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

N = size(A,1);
Q = zeros(N,N);
S = zeros(N,N);
for i = 1:N
  for j = 1:N
    if (i == j)
      Q(i,j) = 0;
    elseif (A(i,j) == 1)
      Q(i,j) = 1;
    else
      Q(i,j) = Inf;
    end
  end
end

for k = 1:N
  for i = 1:N
    for j = 1:N
      S(i,j) = min(Q(i,j), Q(i,k)+Q(k,j));
    end
  end
  Q = S;
end
