function [s, L1] = follow_segment(start_point, I, L0)
%
% FOLLOW_SEGMENT: [s, L1] = follow_segment(start_point, I, L0)
%
% This function is a helper for edge_linker.
%
% INPUT:
% -----
% start_point: coords of start point [row, col]
% I:           binary image
% L0:          binary image indicating whether points have already been labeled or not
%
% OUTPUT:
% ------
% s:           (q x 2) array of points in the segment. First col = row coord;
%                second col = col coord.
% L1:          updated label array (adjusted to take into account the points that
%                were labled during this call of follow_segment
%
% NOTE: We assume a zero border exists around I so that we don't need to 
% do bounds checking when exploring nbhds. Calling this function from
% edge_linker insures the zero border exists.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

% Get size of I for bounds checking
[ir, ic] = size(I);

% Copy L0 to L1
L1 = L0;

% Arrays used for exploring nbhd of a point
di = [-1, 0, 1, 0, -1, -1, 1,  1];
dj = [ 0, 1, 0,-1, -1,  1, 1, -1];

% Allocate space for the segment
smax = 1+sum(sum( (I ~= 0) & (L1 == 0) )); % conservative estimate of segment length
                                           % add 1 since start_point may or may not 
					   % already be marked as labeled.
s = zeros(smax,2);   

% MAIN LOOP
q = 0;
done = 0;
i = start_point(1); j = start_point(2);
while (~done)
  q = q+1;
  s(q,:) = [i, j]; % Add current point to segment
  L1(i,j) = 1;     % mark current point as labeled
  
  neigh = ( (I(i-1:i+1, j-1:j+1)~=0) & (L1(i-1:i+1,j-1:j+1) == 0) ); % unlabled neigbors
  neigh_vec = [neigh(1,2), neigh(2,3), neigh(3,2), neigh(2,1), neigh(1,1), neigh(1,3), neigh(3,3), neigh(3,1)];
  f = find(neigh_vec);
  if (~isempty(f))
    % Find closest unlabeled neighboring point to the current and 
    %   add this new point on to the segment 
    elem = min(f);
    i = i+di(elem);
    j = j+dj(elem);
  else
    done = 1;
  end
end      

s = s(1:q,:);