function v = gaxis()
%
% GAXIS: v = gaxis();
% 
% Redefine axes of a plot based on a rectangle "drawn" on a figure by the user 
% with the mouse.
%
% INPUT:
% -----
% Two mouse clicks at two diagonally opposite corners of the rectangular region
% of interest. (No rectangle is actually drawn.)
%
% OUTPUT:
% ------
% v - (1 X 4) vector with [xmin, xmax, ymin, ymax] used to redefine the axes.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

[x,y] = ginput(2);

if (length(x) == 2)
  xmin = min(x);
  xmax = max(x);
  ymin = min(y);
  ymax = max(y);
  v = [xmin; xmax; ymin; ymax];
  axis([xmin, xmax, ymin, ymax]);
else
  fprintf(1,'ERROR: axes not correctly specified');
  v = [];
end
