function W = generate_hx_test
% GENERATE_HX_TEST: W = generate_hx_test;
%
% Generate synthetic contour stacks for "cheese" and "ball for testing
%
% INPUT:
% -----
% None
%
% OUTPUT:
% ------
% W - cell array with 2 cells. Cell k contains a set of 3D
%       contours corresponding to object k. Object 1 is a triangular 
%       prism (like a piece of cheese) and Object 2 is a ball.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

W = cell(2,1);

%========%
% CHEESE %
%========%
C = cell(3,1); % Define cheese based on three transverse slices
C{1,1} = [0, 0, 0; 1, 0, 0; 0, 1, 0; 0, 0, 0];
C{2,1} = [0, 0, 1; 1, 0, 1; 0, 1, 1; 0, 0, 1];
C{3,1} = [0, 0, 2; 1, 0, 2; 0, 1, 2; 0, 0, 2];

W{1,1} = C;

%========%
% BALL   %
%========%

mu = [3, 3, 1];
R = 1;
dz = (2*R*0.95)/21;
z = (-0.95*R:dz:0.95*R)';
theta = (0: 0.1: (2*pi))';
ov = ones(size(theta,1),1);
K = length(z);
B = cell(K,1);
for k = 1:K
  rho_k = sqrt(R^2 - z(k,1)^2);
  B{k,1} = [mu(1,1)+rho_k * cos(theta), mu(1,2)+rho_k*sin(theta), mu(1,3)+z(k,1) * ov];
end

W{2,1} = B;