function T = get_directory_tree(root_dir)
%
% GET_DIRECTORY_TREE: T = get_directory_tree(root_dir);
%
% Construct a tree representing directory hierarchy below
% root_dir.
%
% INPUT:
% -----
% root_dir - name of root directory at which to start the tree; 
%              root_dir should end with a '/'
%
% OUTPUT:
% ------
% T       - directory tree, which is basically an array of node structures.
%             Each node has fields for name, isdir, children, parent.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

node = 1;
T(node,1).name = root_dir;
T(node,1).fullname = root_dir;
T(node,1).isdir = 1;
T(node,1).parent = 0;
T(node,1).children = [];
examine = [node];

while (length(examine) > 0)
  % Look at first node on examine list 
  curr_dir = T(examine(1)).fullname;
  
  % See what is under this node
  D = dir(curr_dir);
  M = size(D,1);
  if (M > 2)  % exclude . and ..
    for e = 3: size(D,1)
      node = node+1;
      T(node,1).name = D(e).name;
      T(node,1).fullname = [T(examine(1)).fullname, D(e).name];      
      T(node,1).isdir = D(e).isdir;
      if (T(node,1).isdir == 1)
	T(node,1).fullname = [T(node,1).fullname, '/']; % add trailing slash to directories
        examine = [examine; node]; 
      end
      T(node,1).parent = examine(1);
      T(node,1).children = [];
      T(examine(1)).children = [T(examine(1)).children; node];
    end
  end
  examine(1) = [];
end


%  % Expand its name to a full path specification
%  x = examine(1);
%  curr_dir = [T(x).name, '/'];
%  while (T(x).parent ~= 0)
%    x = T(x).parent;
%    curr_dir = [T(x).name, '/', curr_dir];
%  end
  
