function [K, R]  = ginrect(XY);
%
% GINRECT: [K, R] = ginrect(XY);
%
% Determine points in XY that fall inside a series of rectangles specified
% by the user with the mouse. Return indices of these points in a cell array
% along with the vertices of the rectangles in the form [x0 x1 y0 y1]
% with x0 <= x1 and y0 <= y1.
%
% INPUT:
% -----
% XY - (n_points X 2) matrix; first col = x-coordinate, second col = y-coordinate
%
% OUTPUT:
% ------
% K - (n_boxes X 1) cell array; the k-th cell contains indices into rows of XY of
%        points the k-th box.
% R - (n_boxes X 4) matrix; [min_x, max_x, min_y, max_y]
%
% NOTES:
% -----
% Click mouse button 3 to quit.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
x = XY(:,1);
y = XY(:,2);

block = 512;
K = cell(block, 1);
R = zeros(block, 4);

hon;
done = 0;
i = 0;
while (done == 0)
  [rx1, ry1, button1] = ginput(1);
  if (button1 == 3)
    done = 1;
  else
    [rx2, ry2, button2] = ginput(1);  
    if (button2 == 3)
      done = 1;
    else
      i = i+1;

      % Memory management nuisance
      if (i > size(K,1))
	KK = cell(size(K,1)+block, 1);
	for m = 1:size(K,1)
	  KK{m,1} = K{m,1};
	end
	K = KK;
	R = [R; zeros(block,4)];
      end


      R(i,1) = min(rx1, rx2); % x0
      R(i,2) = max(rx1, rx2); % x1
      R(i,3) = min(ry1, ry2); % y0
      R(i,4) = max(ry1, ry2); % y1
      plot( R(i,[1,2,2,1,1]), R(i,[3,3,4,4,3]), 'y');
      K{i,1} = find((x >= R(i,1)) & (x <= R(i,2)) & (y >= R(i,3)) & (y <= R(i,4)));
    end
  end
end

% Squish arrays into compact size
KK = cell(i,1);
for m = 1:i
  KK{m,1} = K{m,1};
end
K = KK;
R = R(1:i,:);

