function [V, E] = graph_from_segments(S)
% 
% GRAPH_FROM_SEGMENTS: [V, E] = graph_from_segments(S);
%
% Given a set of line segments between 2D points, create an equivalent planar graph consisting
% of vertices and links.
%
% INPUT:
% -----
% S  - (s X 4) list of segments, [x0, y0, x1, y1]
%
% OUTPUT:
% ------
% V  - (v X 2) set of vertices (graph nodes)
% L  - (s x 2) set of links
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
[sr,sc] = size(S);
if (sc ~= 4)
  fprintf(1, 'WARNING (graph_from_segments): expecting 2D segments\n');
end
E = zeros(sr, 2);

% Determine set of unqiue segment endpoints
V = unique([S(:,1:2); S(:,3:4)], 'rows');

for i = 1:sr
  ep1x = S(i,1);
  ep1y = S(i,2);
  ind = find((ep1x == V(:,1)) & (ep1y == V(:,2)));
  E(i,1) = min(ind);
  
  ep2x = S(i,3);
  ep2y = S(i,4);
  ind = find((ep2x == V(:,1)) & (ep2y == V(:,2)));
  E(i,2) = min(ind);
end

