function D = hop_distance(V, C)
%
% HOP_DISTANCE: D = hop_distance(V, C);
%
% Take description of a set of cell compartments [in the form of vertices and 
% boundary specifications (each compartment boundary is specified by a set of
% ordered indices into the vertices)] and compute the hop_distance between each
% cell compartment and each other cell compartment. Moving from one cell compartment
% to an adjacent cell compartment is a hop of 1.
%
% INPUT:
% -----
% V  - (n_vert X 2) matrix; each row contains coordinates of one vertex
% C  - (n_cells X 1) cell array; each cell contains ordered set of indices into V such
%        that the connecting the dots traces out the boundary of the cell compartment.
%
% OUTPUT:
% ------
% D  - (n_cells X n_cells) matrix; D(i,j) = hop distance between cell i and cell 3.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
n_vertices = size(V,1);
n_cells = size(C,1);

% First step is to construct the connectivity/adjacency matrix
A = zeros(n_cells, n_cells);
for i = 1:n_cells
  ind_i = C{i,1};
  for j = 1:n_cells
    ind_j = C{j,1};
    for k = 1:length(ind_i)
      if (any(ind_j == ind_i(k)))
	A(i,j) = 1;
      end
    end
  end
end

% Next apply Floyd's algorithm to get the all-pairs hop distances
D = floyd(A);
