function icell_movie(icell, dt)
%
% ICELL_MOVIE: ilist_movie(icell, dt);
%
% Display a cell array with image filenames as a movie in a new figure window.
%
% INPUT:
% -----
% icell  - cell array with list of image filenames (with paths if not in current dir)
% dt     - time delay between displayed frames (def: dt = 1)
%
% OUTPUT:
% ------
% Display frames in a new figure
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% ascale.m
% vread.m
% pfx.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 2)
  dt = 1;
end

figure;
set(gcf, 'DoubleBuffer', 'on');

N = size(icell,1);
for n = 1:N
  skip = 0;
  iname = icell{n,1};
  
  % Check on file format
  view_fmt = 0;
  pds_fmt  = 0;
  L = length(iname);
  if (L >= 4)
    if (iname(L-3:L) == '.sdt')
      view_fmt = 1;
      if (L > 4)
	iname = iname(1:L-4);
      else
	iname = '';
      end
    elseif (strcmpi(iname(L-3:L),'.img') == 1)
      pds_fmt = 1;
    end
  end

  if (view_fmt == 1)
    I = vread(iname);
    GC2;
%  elseif (pds_fmt == 1)
%    [I, NV] = pds_read(iname);
  else
    I = imread(iname);
  end
  
  if (ndims(I) == 2)
    image(ascale(double(I)));
    GC2;
  elseif (ndims(I) == 3)
    image(I(:,:,1:3));
  else
    fprintf(1, 'WARNING (ilist_movie): file %s has inappropriate dimensions --- skipping\n', iname);
    skip = 1;
  end
  if (~skip)
    axis('square');
    [p,f,x] = pfx(iname);
    title_text = iname(f:x-1);
    ind = find(title_text == '_');
    title_text(ind) = ' ';
    title(title_text);
    pause(dt);
  end
end

keyboard
