function B = icluster_bbox(L, nobj)
%
% ICLUSTER_BBOX: B = icluster_bbox(L, nobj);
%
% Given a label image L, determine the bounding box (minimum bounding rectangle
%   for each cluster.
%
% INPUT:
% -----
% L    - label image (e.g., from icluster)
% nobj - number of objects (number of labels in L)
%
% OUTPUT:
% ------
% B    - (nobj x 4) matrix. [xmin, xmax, ymin, ymax]
%
% NOTE:
% ----
% x values correspond to *column* indices, y values correspond to *row* indices
%
% HISTORY:
% -------
% 2004/03/01 (MCB) - Added a check for empty clusters; bounding box for those will be 
%   reported as [0 0 0 0]
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

B = zeros(nobj, 4);
for l = 1:nobj
  [y,x] = find(L == l);
  if (~isempty(y))
    B(l,:) = [min(x), max(x), min(y), max(y)];
  end
end