function Cset = icluster_contours(L, nobj);
%
% ICLUSTER_CONTOURS: Cset = icluster_contours(L, nobj);
%
% Detect edges in a binary image using contour following.
%
% INPUT:
% -----
% L      - label image (each pixel is an integer in range [0, nobj])
% nobj   - number of objects in L
%
% OUTPUT:
% ------
% Cset  - cell array of contours, Cset{i,1} is an n(i) X 2 array of the point
%         coordinates along contour i. First col is x, second col is y.
%
% HISTORY:
% -------
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% bitmap_contours.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

[lr, lc] = size(L);

Cset = cell(nobj, 1);
for l = 1:nobj
  I = (L == l);
  Cset{l,1} = bitmap_contours(I);
end
