function [C_new, nz_new] = icluster_elim(C, nz, elim)
%
% ICLUSTER_ELIM: [C_new, nz_new] = icluster_elim(C, nz, elim);
%
% Eliminate clusters from C having indices given in elim then
%   compress the remaining cluster labels to be consecutive.
%
% INPUT:
% -----
% C    - (nr x nc) cluster label image
% nz   - number of clusters
% elim - vector of clusters to eliminate
%
% OUTPUT:
% ------
% C_new  - new cluster label image
% nz_new - new number of clusters
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

ne = length(elim);
nz_new = nz - ne;
if (ne > 0)
  [nr, nc] = size(C);
  C_new = zeros(nr, nc);

  % Set up F to map old labels to new labels
  keep = ones(nz,1);
  keep(elim) = 0;
  F = cumsum(keep) .* keep;

  for i =1:nr
    for j = 1:nc
      if (C(i,j) ~= 0)
        C_new(i,j) = F(C(i,j));
      end
    end
  end
  
else
  C_new = C;
end  
