function E = icluster_ellipse_params(A)
%
% ICLUSTER_ELLIPSE_PARAMS: E = icluster_ellipse_params(A);
%
% Given a label image L, determine the ellipse parameters (n, x, y, a, b, theta)
%
% INPUT:
% -----
% A    - (nobj X 6) matrix fromicluster_moments.m
%
% OUTPUT:
% ------
% E    - (nobj x 6) matrix. 1st col = # of elements, 2nd col = x_mean, 3rd col = y_mean
%           4th col = a, 5th col = b, 6th col = theta (degrees)
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 3)
  EPS = 0.0001; 
end

nobj = size(A,1);
E = zeros(nobj,6);
E(:,1:3) = A(:,1:3);
for i = 1:nobj
  S = [A(i,4), A(i,5); A(i,5), A(i,6)];
  [V, D] = symeig2(S);
  E(i,4) = 2*sqrt(D(2,2)); % major axis
  E(i,5) = 2*sqrt(D(1,1)); % minor axis
  E(i,6) = atan2(V(2,2), V(1,2))*180/pi; % orientation of major axis
end
