function [C_new, nz_new] = icluster_keep(C, nz, keep)
%
% ICLUSTER_KEEP: [C_new, nz_new] = icluster_keep(C, nz, keep);
%
% Keep clusters in C having indices given in keep then
%   compress the remaining cluster labels to be consecutive.
%
% INPUT:
% -----
% C    - (nr x nc) cluster label image
% nz   - number of clusters
% keep - vector of clusters to keep
%
% OUTPUT:
% ------
% C_new  - new cluster label image
% nz_new - new number of clusters
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

nk = length(keep);
nz_new = nk;
if (nz_new < nz)
  [nr, nc] = size(C);
  C_new = zeros(nr, nc);

  % Set up F to map old labels to new labels
  v = zeros(nz,1);
  v(keep) = 1;
  F = cumsum(v) .* v;

  for i =1:nr
    for j = 1:nc
      if (C(i,j) ~= 0)
        C_new(i,j) = F(C(i,j));
      end
    end
  end
  
else
  C_new = C;
end  
