function ind = id_contours(Cset, x, y, dthr)
%
% ID_CONTOURS: ind = id_contours(Cset, x, y, dthr);
%
% Return indices of any contours that pass close enough (within
% dthr) to the point (x,y)
%
% INPUT:
% -----
% Cset  - cell array with a set of contours
% x,y   - coordinates of a point
% dthr  - distance threshold
%
% OUTPUT:
% ------
% ind   - vector of indices
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

N = size(Cset,1);
ind = zeros(N,1);
k = 0;
for n = 1:N
  C = Cset{n,1};
  [cr, cc] = size(C);
  D = C - ones(cr,1)*[x,y];
  d = sqrt(sum(D.^2, 2));
  if (min(d) <= dthr)
    k = k+1;
    ind(k,1) = n;
  end
end

ind = ind(1:k,1);
