function L = image_from_compartments(V, C, lsize)
%
% IMAGE_FROM_COMPARTMENTS: L = image_from_compartments(V, C, lsize);
%
% Given a set of cell compartments (specified by vertices and paths
%   through the vertices that describe cell compartment boundaries),
%   construct a label image in which each pixel has the index of the
%   compartment it is contained within.
%
% INPUT:
% -----
% V  - (n_vertices X 2)
% C  - (n_cells X 2)
% lsize - (2 X 1) vector with the desired output image size
%
% OUTPUT:
% ------
% L - (lr X lc) image
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% polygon_mask.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
L = zeros(lsize(1), lsize(2));
for k=1:size(C,1), 
  Ck=C{k,1}; 
  Ck = [Ck'; Ck(1)];
  if (~ (any(isinf(V(Ck,1))) | any(isinf(V(Ck,2)))) )
    % we ignore compartments with vertices at infinity; these sometimes
    %   arise if the compartments are computed by voronoi method
    mask = polygon_mask(lsize, V(Ck,1), V(Ck, 2)); 
    L = L+k*mask(1:lsize(1),1:lsize(2)).*(L==0);
  end
end
