function img_movie(base, suffix, f0, f1, df, dt, fwidth)
%
% IMG_MOVIE: img_movie(base, suffix, f0, f1, df, dt, fwidth);
%
% INPUT:
% -----
% base   - base filename for images in the sequence
% suffix - suffix for image names, including the extension
%            (use .sdt for view images)
% f0     - initial frame number
% f1     - final frame number
% df     - increment for stepping through frames (def: df=1)
% dt     - time delay between displayed frames (def: dt = 1)
% fwidth - [OPTIONAL] to allow for fixed width frame numbers, e.g., img0001.jpg
%            set fwidth to the width (so 4 in the example above). Set fwidth to
%            0 to get conventional numbering.
%
% OUTPUT:
% ------
% Display frames in a new figure
%
% EXAMPLE:
% -------
% Suppose you have frames image_1.jpg, image_2.jpg, and image_3.jpg in
% directory /proj/data/images. To display these as a movie with this
% function, you would say:
%
% >> img_movie('/proj/data/images/image_', '.jpg', 1, 3, 1, 0.5);
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% vread.m
% pds_read.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 7)
  fwidth = 0;
end
if (fwidth > 0)
  fmt = ['%.',int2str(fwidth),'d'];
end

if (nargin < 6)
  dt = 1;
end

if (nargin < 5)
  df = 1;
end

figure;
set(gcf, 'DoubleBuffer', 'on');

% Check on file format
view_fmt = 0;
pds_fmt  = 0;
L = length(suffix);
if (L >= 4)
  if (suffix(L-3:L) == '.sdt')
    view_fmt = 1;
%    if (L > 4)
%      suffix = suffix(1:L-4);
%    else
%      suffix = '';
%    end
  elseif (strcmpi(suffix(L-3:L),'.img') == 1)
    pds_fmt = 1;
  end
end

for f = f0:df:f1
  if (fwidth == 0)
    ff = int2str(f);
  else
    ff = sprintf(fmt, f);
  end
  name = [base, ff, suffix];
  if (~fexists(name))
    fprintf(1, 'WARNING (img_movie): %s not found - skipping\n', name);
  else
    if (view_fmt == 1)
      I = vread(name);
      GC2;
    elseif (pds_fmt == 1)
      [I, NV] = pds_read(name);
    else
      I = imread(name);
    end

    e = 1;
    [nr, nc, nd] = size(I);
    if (nd == 3)
      I = rgb2gray(I);
    elseif (nd == 4)
      I = I(:,:,1:3);
      nd = 3;
    end
    image(I(e:(nr-e+1),e:(nc-e+1), 1:nd));
    if (size(I,3) == 1)
      GC2;
  %%    S = edge_detection(I,3, 0.3,0.1);
  %%    hon;
  %%    plot_edges(S, 0, 'r', 2);
    end
  %  image(scale(I,-Inf,Inf,1,255));
  %%  image(scale(mean(I,3),-Inf,Inf,1,255));
  %%  GC2;
  %%  image(I(:,:,1:3));
  %  axis('square');
    title(ff);
    pause(dt);
    hof;
  end
end
