function Is = imsmooth(I, sp)
%
% IMSMOOTH: Is = imsmooth(I, sp);
%
% Smooth an image by repeated passes with a 3 tap binomial coefficient filter. 
% (This approach is commonly used as an efficient approximation 
% of Gaussian smoothing.)
%
% INPUT:
% -----
% I  - input image
% sp - number of smoothing passes with a 3-tap binomial filter. More passes
%        is like smoothing with a broader Gaussian. This is equivalent to using
%        a binomial coefficient filter with 2*sp+1 taps.
%
% OUTPUT:
% ------
% Is     - smoothed image (same size as I)
%
% NOTE:
% ----
% We don't do anything special at image borders so effectively lose some data
% around the border of the image. The amount lost depends on the number of smoothing
% passes.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

g = [1 2 1]'/4; 
Is = I;
if (sp > 0)
  for i = 1:sp
    Is = conv2(g, g', Is, 'same');
  end
end
