function C = lineage_label_match(LL1, LL2)
%
% LINEAGE_LABEL_MATCH: C = lineage_label_match(LL1, LL2);
%
% Find correspondences (matching lineage labels) given two sets of lineage labels. Ignore
% matches between '0' labels.
%
% INPUT:
% -----
% LL1  - (n1 x 1) cell array with lineage (tree) labels like 1.2.3
% LL2  - (n2 x 1) cell array with lineage (tree) labels
%
% OUTPUT:
% ------
% C    - (M x 2) matrix; with tentative correspondences between lineage labels
%          each row of C = [i, j] where LL1{i,1} is a match for LL2{j,1}
%
% NOTE:
% ----
% The label '0' is not allowed to match anything.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

n1 = size(LL1,1);
n2 = size(LL2,1);

C = zeros(n1*n2,2);
k = 0;
for i=1:n1
  if (strcmp(LL1{i,1}, '0') == 0)
    for j=1:n2
      if (strcmp(LL2{j,1}, '0') == 0)  
	if (strcmp(LL1{i,1}, LL2{j,1}) == 1)
	  k = k+1;
	  C(k,:) = [i, j];
	end
      end
    end
  end
end
C = C(1:k,:);
