function L = linkage_from_compartments(G)
%
% LINKAGE_FROM_COMPARTMENTS: L = linkage_from_comaprtments(G)
%
% Given a stack of segmentation results (in the form of boundary contours for each
% object at each stack level), create a linkage structure which expresses the affinitity
% for compartment i in level k for compartment j in level k+1. The afifnitity is based
% on the intersection area normalzied by the union area.
% 
% INPUT:
% -----
% G - (N x 1) cell array; G{k,1} contains a cell array in which each cell is a boundary
%       contour of some compartment or nucleus in stack level k. 
%
% OUTPUT:
% ------
% L - (N-1 x 1) cell array, where N is the nmumber of stack levels. L{k,1} contains the
%        affinity or linkage between each compartment in level k and each compartment in
%        level k+1 based on the intersection area normalized to the union area.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% polygon_mask.m
% randcol.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
mr = 201;
mc = 201;
N = size(G,1);

% HACK
N = 19;

L = cell(N-1,1);

old_mask = zeros(mr, mc);
for i=1:N-1
  Pfg = G{i,1};
  mask = zeros(mr, mc);
  for j = 1:size(Pfg,1)
    xy = Pfg{j,1};
    if (~isempty(xy))
      X = 100 + 2 *xy(:,1);
      Y = 100 + 2 *xy(:,2);
      
      pm = polygon_mask([mr; mc], X, Y);
      mask = mask + j*pm.*(1-mask);
    end
  end  
  
  icluster_display(mask);
  title(int2str(i));
  pause(1);
  
  
  n_old = max(max(old_mask));
  n_new = max(max(mask));
  AB    = zeros(n_old, n_new);
  ABbar = zeros(n_old, n_new);  
  AbarB = zeros(n_old, n_new);  
  for k=1:n_old
    for l = 1:n_new
      AB(k,l)    = sum(sum((old_mask == k) & (mask == l)));
      ABbar(k,l) = sum(sum((old_mask == k) & (mask ~= l)));
      AbarB(k,l) = sum(sum((old_mask ~= k) & (mask == l)));      
    end
  end
  L{i,1} = AB./(AB + ABbar + AbarB + 0.001);
  
  old_mask = mask;
end

keyboard
figure; 
hon;
cvec = randcol(17,0.3);
for k=1:17
  R = L{k,1};
  [m,n] = size(R);
  plot(k*ones(m,1), 1:m, 'bo', 'Markersize', 12, 'Linewidth', 2);
  plot((k+1)*ones(n,1), 1:n, 'rx', 'Markersize', 12, 'Linewidth', 2);
  for i=1:m
    for j=1:n
      w = floor(sqrt(R(i,j))*10); 
      if (w > 0)
	plot([k,k+1], [i,j], 'Color', cvec(k,:), 'Linewidth',w);
      end
    end
  end
end;
set(gca, 'XTickLabels', 1:2:17); %% HACK - why do we need this?
axis('ij')
