function C = linked_contours(G, T, Nm)
%
% LINKED_CONTOURS: C = linked_contours(G, T, Nm);
%
% Starting from measure of edginess and orientation of edge at each pixel,
% construct a set of contours.
%
% INPUT:
% -----
% G -  edginess image; values designate edge strength
% T -  orientation image; values designate orientation of needle perpendicular 
%        to edge (in radians), e.g., gradient direction
%
% OUTPUT:
% ------
% C -  linked contours
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% zero_crossings.m
% link_segments.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

Q = [0, 0, -1, 0, 1, 0, 0]/2;
D = fliplr(Q);

% BUG: Fixed 20060627
Gx = conv2(     1, D(1,:), G, 'same');
Gy = conv2(D(1,:),      1, G, 'same');


Z = (Gx .* cos(T) + Gy .* sin(T)) .* (~Nm);

[zr, zc] = size(Z);
[E,B] = zero_crossings(Z(3:zr-2, 3:zc-2));
E = E+2; % adjust coordinates back to original system
B = B+2;

[Ce, Cb, nobj] = link_segments(E, B, 0.25);

C = cell(nobj, 1);
for c = 1:nobj
  e = find(Ce == c);
  b = find(Cb == c);
  if (size(b,1) > 0)
    bb = [6*b-5, 6*b-4, 6*b-3, 6*b-2, 6*b-1, 6*b];
  else
    bb = [];
  end

  if ((length(e) + length(b)) > 0)
    C{c,1} = [E(e, :); B(bb,:)];
  else
    C{c,1} = [];
  end
end

fprintf(1, 'MESSAGE (linked_contours): about to return\n');
keyboard
