function Y= median_filter(X, w)
%
% MEDIAN_FILTER: Y = median_filter(X, w);
%
% Apply median filter to an image X. Pixel (i,j) in the output image (Y) contains the
% median value over a (w x w) window centered at pixel (i,j) in the input image (X).
%
% INPUT:
% -----
% X - (nr X nc) image
% w - scalar; window size (typically a small odd integer such as 3 or 5).
%
% OUTPUT:
% ------
% Y - (nr X nc) image
%
% NOTE:
% ----
% Values on a band of width approximately w/2 along the image border are set to 0.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

wm = floor((w-1)/2);
wp = floor(w/2);

[nr,nc] = size(X);
Y = zeros(nr,nc);

for i = wm+1:nr-wp
  for j = wm+1:nc-wp
    W = X(i-wm:i+wp,j-wm:j+wp);
    Y(i,j) = median(W(:));
  end
end
  
