function meristem_surface(ibase, isuff, f0, f1, fwidth, oname)
% meristem_surface: meristem_surface(ibase, isuff, f0, f1, fwidth, oname)
% 
% Produces an amira surface file representation of the meristem surface.
%
%INPUT:
%------
% ibase - image base name whole path including file name up to the numerical 
%         counter for stack level.
% isuff - image suffix eg .tif
% f0    - start frame
% f1    - end frame
% fwidth - width of frame number for fixed-width formats eg. 3 for img001.jpg
% fname  - the complete filename including path to save the amira surface text file
%
% OUTPUT:
%---------
% a text file with filename fname that is the amira surface file representation.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% median_filter.m
% remove_appendages.m
% icluster.m
% icluster_moments.m
% icluster_elim.m
% edge_detection.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

mincnt = 1e04;
nf = f1-f0+1;
F = cell(nf,1);
k = 0;
for f = f0:f1
  iname = construct_fname(ibase, isuff, f, fwidth);
  I = imread(iname);
  I = sqrt(double(I));
  Y = median_filter(I, 5);
  I = (abs(Y - Y(1000,400)) < 1);
  Q = remove_appendages(I, 3);
  [L, nobj] = icluster(Q, ones(2,1));
  M = icluster_moments(L, nobj, 1e-03);
  [Ln, nobjn] = icluster_elim(L, nobj, (M(:,1) < mincnt));
  S = edge_detection(double(Ln > 0), 3, 0.4, 0.2);
  k = k+1;
  F{k, 1} = S;
end

keyboard