function mosaic(chips, dr, dc, bdr, vals, arrange)
%
% MOSAIC: mosaic(chips, dr, dc, bdr, vals, arrange);
%
% This function will make a collage of chips. If desired,
% vals may be printed alongside the chips. Also, the
% chips may be arranged in increasing or decreasing order.
%
% chips     - matrix with chips strung out as rows
% dr, dc    - size of chips
% bdr       - border around chips
% [vals]    - a vector of values; each chip is associated with a value
% [arrange] - a flag; 1 = arrange in ascending order by value,
%                    -1 descending, 
%                     0 do not alter the ordering
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% reform.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

%Get all input information
  if (nargin < 6)
    arrange = 0;
  end
  if (nargin < 5)
    print_vals = 0;
  else 
    print_vals = 1;
  end

  if (arrange == 1)
    [V,index] = sort(vals);
    chips = chips(index,:);
  elseif (arrange == -1)
    tmp = -1 * vals;
    [V,index] = sort(tmp);
    V = -1 * V;
    chips = chips(index,:);
  else
    if (print_vals ~= 0)
      V = vals;
    end
  end

  %reform chips into a collage
%%MCB 05/22/98  C = reform(scale(chips,-Inf,Inf,1,128), dr, dc, bdr);
  C = reform(chips, dr, dc, bdr);

% For hard copies, it is useful for area between chips to be white
%  C = reform(scale(chips,-0.25,0.25,1,128), dr, dc, bdr, 128);

  figure('Position',[50,50,800,800]); image(C); GC1
  axis('off');

  if (print_vals ~= 0)
    %print value of each chip next to it
    k=1;
    for i=0:dr+bdr:size(C,1)
      for j=dc:dc+bdr:size(C,2)
        if k <= size(chips,1)
          text(j,i,int2str(V(k,1)),'Color', 'c');
          k=k+1;
        end
      end
    end

%    %print response value of the last chip in each row next to it
%    j = size(C,2);
%    ii = 1;
%    for i=dr/2:dr+bdr:size(C,1)
%      k = ii * round(size(C,2)/(dc+bdr));
%      if k <= size(chips,1)
%        text(j,i,num2str(V(k)));
%        ii=ii+1;
%      end
%    end
%    %print response value of last chip at end of last row
%    text(j,i,num2str(V(size(chips,1))));
  end

