function b = myfir1(N, Wn)
%
% MYFIR1: b = myfir1(N, Wn)
%
% Design an N-th order lowpass filter. The filter coefficients are
% returned in a length N+1 vector b. The cut-off frequency Wn must 
% be in the interval (0, 1.0) with 1.0 corresponding to half the 
% sample rate.
%
% Adapted from MATLAB signal processing toolbox routine fir1.m
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

nw = 0;
N = N + 1;
odd = rem(N, 2);
wind = 0.54 - 0.46*cos(2*pi*(0:N-1)'/(N-1));


fl = Wn/2;
c1=fl;
if (fl >= .5 | fl <= 0)
   error('Frequency must lie between 0 and 1')
end 

nhlf = fix((N + 1)/2);
i1=1 + odd;

if odd
   b(1) = 2*c1;
end
xn=(odd:nhlf-1) + .5*(1-odd);
c=pi*xn;
c3=2*c1*c;
b(i1:nhlf)=(sin(c3)./c);
b = real([b(nhlf:-1:i1) b(1:nhlf)].*wind(:)');
gain = abs(polyval(b,1));
b = b/gain;

return;
