function R = mywatershed(I)
%
% MYWATERSHED: R = mywatershed(I);
%
% INPUT:
% -----
% I - image containing integer values
%
% OUTPUT:
% ------
% R - watershed image
%
% ---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% neighbors.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

fictitious_pixel = [Inf, Inf];
MASK = -2;
INIT = -1;
WSHED = 0;

[nr,nc] = size(I);
I = double(I);
R = INIT * ones(nr, nc);
D = zeros(nr, nc);

% Initialize FIFO queue
N_QUEUE_MAX = nr*nc;
n_queue = 0;
head = 1;
tail = 1;
F = cell(N_QUEUE_MAX,1);


% Create histogram
h_min = min(I(:));
h_max = max(I(:));
B = (h_min-0.5:1:h_max+0.5)';
n_bins = length(B)-1;  %ignore last bin
H = histc(I(:), B);

% Sorting
C = cumsum([1; H(1:n_bins-1)]); % CDF
cnt = zeros(n_bins, 1);
S = zeros(nr*nc, 2);
for i = 1:nr
  for j = 1:nc
    v = I(i,j);
    b = 1+floor(v-h_min+0.5);
    S(C(b)+cnt(b),:) = [i, j];
    cnt(b) = cnt(b)+1; 
  end
end

% MAIN LOOP
current_label = 0;
for b = 1:n_bins
  h = h_min + (b-1); % actual threshold
  % Geodesic SKIZ of level h-1 inside level h
  for k = 1:H(b)
    p = S(C(b)+k-1,:);
    R(p(1), p(2)) = MASK;
    
    % Check neighbors q of p to see if any have R value > 0
    %   or R == WSHED
    Q = neighbors(p, [nr, nc], 8);
    for j = 1:size(Q,1)
      q = Q(j,:);
      if ( (R(q(1), q(2)) > 0) | (R(q(1), q(2)) == WSHED) )
        D(p(1), p(2)) = 1;
	%%--
        %% F = fifo_add(p, F);
	if (n_queue == N_QUEUE_MAX)
	  fprintf(1, 'ERROR (watershed): queue overrun\n');
	  return
	end
	F{tail,1} = p;
	n_queue = n_queue+1;
	tail = tail+1;
	if (tail > N_QUEUE_MAX)
	  tail = tail - N_QUEUE_MAX;
	end
	%%--
	break;
      end
    end
  end

  current_dist = 1;
  %%--
  %% F = fifo_add(fictitious_pixel, F);  
  if (n_queue == N_QUEUE_MAX)
    fprintf(1, 'ERROR (watershed): queue overrun\n');
    return
  end
  F{tail,1} = fictitious_pixel;
  n_queue = n_queue+1;
  tail = tail+1;
  if (tail > N_QUEUE_MAX)
    tail = tail - N_QUEUE_MAX;
  end
  %%--
  while (1)
    %%--
    %% [p, F] = fifo_first(F);
    if (n_queue == 0)
      fprintf(1, 'ERROR (watershed): queue underrun\n');
      return
    end
    p = F{head,1};
    n_queue = n_queue-1;
    head = head + 1;
    if (head > N_QUEUE_MAX)
      head = head - N_QUEUE_MAX;
    end
    %--
    if (all(p == fictitious_pixel))
      if (n_queue == 0)
	break;
      else
	%%--
	%% F = fifo_add(fictitious_pixel, F);  
	if (n_queue == N_QUEUE_MAX)
	  fprintf(1, 'ERROR (watershed): queue overrun\n');
	  return
	end
	F{tail,1} = fictitious_pixel;
	n_queue = n_queue+1;
	tail = tail+1;
	if (tail > N_QUEUE_MAX)
	  tail = tail - N_QUEUE_MAX;
	end
	%%--
	current_dist = current_dist + 1;
	%%--
	%% [p, F] = fifo_first(F);
	if (n_queue == 0)
	  fprintf(1, 'ERROR (watershed): queue underrun\n');
	  return
	end
	p = F{head,1};
	n_queue = n_queue-1;
	head = head + 1;
	if (head > N_QUEUE_MAX)
	  head = head - N_QUEUE_MAX;
	end
	%--
      end
    end
    
    Q = neighbors(p, [nr, nc], 8);
    for j = 1:size(Q,1)
      q = Q(j,:);
      if ( (D(q(1), q(2)) < current_dist) & ((R(q(1), q(2)) > 0) | (R(q(1), q(2)) == WSHED)) )
	% i.e., q belongs to an already labeled basin or to the watersheds
	if (R(q(1), q(2)) > 0)
	  if ( (R(p(1), p(2)) == MASK) | (R(p(1), p(2)) == WSHED) ) 
	    R(p(1), p(2)) = R(q(1), q(2));
	  elseif (R(p(1), p(2)) ~= R(q(1), q(2)))
	    R(p(1), p(2)) = WSHED;
	  end
        elseif (R(p(1), p(2)) == MASK)
	  R(p(1), p(2)) = WSHED;
        end
      elseif ( (R(q(1), q(2)) == MASK) & (D(q(1), q(2)) == 0) )
	D(q(1), q(2)) = current_dist+1;
	%%--
	%% F = fifo_add(q, F);  
	if (n_queue == N_QUEUE_MAX)
	  fprintf(1, 'ERROR (watershed): queue overrun\n');
	  return
	end
	F{tail,1} = q;
	n_queue = n_queue+1;
	tail = tail+1;
	if (tail > N_QUEUE_MAX)
	  tail = tail - N_QUEUE_MAX;
	end
	%%--
      end
    end
  end % while
  
  % Check if new minima have been discovered
  for k = 1:H(b)   %% for every pixel p s.t. I(p) = h
    p = S(C(b)+k-1,:);
    D(p(1), p(2)) = 0; % reset dist associated with p to 0
    if (R(p(1), p(2)) == MASK)
      current_label = current_label + 1;
      %%--
      %% F = fifo_add(p, F);  
      if (n_queue == N_QUEUE_MAX)
	fprintf(1, 'ERROR (watershed): queue overrun\n');
	return
      end
      F{tail,1} = p;
      n_queue = n_queue+1;
      tail = tail+1;
      if (tail > N_QUEUE_MAX)
	tail = tail - N_QUEUE_MAX;
      end
      %%--

      R(p(1), p(2)) = current_label;
      while (n_queue > 0)
	%%--
	%% [q, F] = fifo_first(F);
	if (n_queue == 0)
	  fprintf(1, 'ERROR (watershed): queue underrun\n');
	  return
	end
	q = F{head,1};
	n_queue = n_queue-1;
	head = head + 1;
	if (head > N_QUEUE_MAX)
	  head = head - N_QUEUE_MAX;
	end
	%--
	
	Q = neighbors(q, [nr,nc], 8);
	for j = 1:size(Q,1)
	  r = Q(j,:);
	  if (R(r(1), r(2)) == MASK)
	    %%--
	    %% F = fifo_add(r, F);  
	    if (n_queue == N_QUEUE_MAX)
	      fprintf(1, 'ERROR (watershed): queue overrun\n');
	      return
	    end
	    F{tail,1} = r;
	    n_queue = n_queue+1;
	    tail = tail+1;
	    if (tail > N_QUEUE_MAX)
	      tail = tail - N_QUEUE_MAX;
	    end
	    %%--
	    R(r(1), r(2)) = current_label;
	  end
	end
      end
    end
  end
end % b