function N = neighbors(p, d, t)
%
% NEIGHBORS: N = neighbors(p, d, t);
%
% INPUT:
% -----
% p - (1 X 2) vector with point coordinates [i,j]
% d - (1 X 2) vector with image size [nr, nc]
% t - scalar; topology for neighbors (e.g., 8-connected)
%
% OUTPUT:
% ------
% N - (n X 2) vector of point coordinates for neighbors
%
% ---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
if (t == 8)
  N8 = [-1,-1; -1, 0; -1, 1; 0,-1; 0,1; 1,-1; 1,0; 1,1];  
  N = ones(8,1) * p + N8;
elseif (t == 4)
  N4 = [-1,0; 0,-1; 1,0; 0,1];
  N = ones(4,1) * p + N4;
elseif (t == 6)
  N6 = [-1,-1; -1,0; 0,-1; 0,1; 1,0; 1,1];
  N = ones(6,1) * p + N6;  
else
  fprintf(1, 'ERROR (neighbors): unrecognized topolgy = %d\n', t);
  N = [];
end
  
keep = ( (N(:,1) >= 1) & (N(:,1) <= d(1)) & (N(:,2) >= 1) & (N(:,2) <= d(2)) );
N = N(keep, :);