function M = nonmax_suppression(Z, Theta)
%
% NONMAX_SUPPRESSION: M = nonmax_suppression(Z, Theta);
%
% Eliminate points Z(y,x) that are not local maxima along the Theta(y,x) direction. 
%
% If Theta(y,x) is more horizontal, then we step forward or backward one column
% (x +/- 1) and interpolate the z values for the resulting non-integral y's.
%
% If Theta(y,x) is more vertical, then we step up or down one row (y +/- 1) and interpolate
% the z values for the resulting non-integral x's.
%
% INPUT:
% -----
% Z     - image
% Theta - direction
%
% NOTE:
% ----
% Theta is defined in the x-y coordinate system where x is across and y is down.
% 
% HISTORY:
% -------
% 2004/05/04 (MCB) - Noticed a potential bug with the interpolation. Was using code
%   like ypf = floor(yp); ypc = ceil(yp);  and then zp = ...
%   This code will not work correctly in the (unlikely) event that yp falls on an
%   integer value so fixed below.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

[zr,zc] = size(Z);
M = zeros(zr, zc);

%for y = 2:zr-1
%  for x = 2:zc-1
% HACK %
for y = 3:zr-2
  for x = 3:zc-2
    z = Z(y,x);
    t = tan(Theta(y,x));
    if (abs(t) < 1)
      xp = x+1; yp = y+t; ypf = floor(yp); ypc = ypf+1;
      zp = (ypc-yp)*Z(ypf, xp) + (yp-ypf)*Z(ypc,xp);
      
      xm = x-1; ym = y-t; ymf = floor(ym); ymc = ymf+1;
      zm = (ymc-ym)*Z(ymf, xm) + (ym-ymf)*Z(ymc,xm);
    else
      xp = x+1/t; yp = y+1; xpf = floor(xp); xpc = xpf+1;
      zp = (xpc-xp)*Z(yp, xpf) + (xp-xpf)*Z(yp,xpc);
      
      xm = x-1/t; ym = y-1; xmf = floor(xm); xmc = xmf+1;
      zm = (xmc-xm)*Z(ym, xmf) + (xm-xmf)*Z(ym,xmc);      
    end
    if ((z >= zp) & (z >= zm))
      M(y,x) = 1;
    end
  end
end
