function F = nucleus_stack(ibase, isuff, f0, f1, fwidth, h)
% NUCLEUS_STACK: nucleus_stack(ibase, isuff, f0, f1, fwidth, df)
%
% Extract set of contours from each level in an image stack.
%
% INPUT:
% -----
% ibase  - image basename
% isuff  - image suffix
% f0     - start frame
% f1     - end frame
% fwidth - width of frame number for fixed-width formats (e.g., img0001.jpg, img0012.jpg)
%             or 0 for natural-width formats (e.g., img1.jpg, img12.jpg)
% h      - half-width of depth averaging
%
% OUTPUT:
% ------
% F -    - cell array; each cell records the set of contours extracted at a particular
%          level in the image stack.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% construct_fname.m
% scale_space.m
% ggradient.m
% edge_detection.m
% randcol.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

% From MCB: Currently I just have these parameters hard-wired in;
% should probably add a structure argument, p, that
% allows user to override or use the values below as
% default.
hi_thr = 0.1;
lo_thr = 0.01;
tscale  = 5;
dthr = 5;
lthr = 7;

q = ones(2*h+1,1); % just use flat (boxcar) smoothing for now
q = q/sum(q);

% Read first frame to get size information
fname = construct_fname(ibase, isuff, f0, fwidth);
I = imread(fname);
nr = size(I,1);
nc = size(I,2);
nd = size(I,3);

F = cell(f1-f0-2*h+1,1);
ff = 0;
for f = f0+h:f1-h
  N = zeros(nr, nc);
  for k = -h:h
    fname = construct_fname(ibase, isuff, f+k, fwidth);
    I = imread(fname);
    if (nd == 3)
      N = N + q(k+h+1) * double(squeeze(I(:,:,2)));
    else
      N = N + q(k+h+1) * double(I);
    end
  end
  Ns = scale_space(N, tscale);
  
  [G, T] = ggradient(Ns, 0,  1);
  fig(sqrt(G));
  title(['Gradient Mag: Img ', int2str(f)], 'Fontsize', 18);
  fig(sqrt(Ns));hon;
  title(int2str(f), 'Fontsize', 18);
  
  S = edge_detection(Ns, 0, hi_thr, lo_thr);
  m = size(S,1);
  
  % apply closure test
  d = zeros(m,1);
  l = zeros(m,1);  
  for i = 1:m
    s = S{i,1};
    l(i) = size(s,1);
    d(i) = sqrt(sum( (s(1,:) - s(l(i),:)).^2 ));
  end

  n_keep = sum((d < dthr) & (l > lthr));
  Skeep = cell(n_keep, 1);
  k = 0;
  for i = 1:m
    if ((d(i) < dthr) & (l(i) > lthr))
      k = k+1;
      col = randcol(1, 0.5);
      s = S{i,1};
      s = [s; s(1,:)];
      Skeep{k,1} = s;
      plot(s(:,1), s(:,2), 'Color', col, 'linewidth', 2);
%%      plot(s(:,1), s(:,2), 'Color', 'r', 'linewidth', 2);
    end
  end
  ff = ff+1;
  F{ff, 1} = Skeep;

  pause(2);
  
  hof
end

%keyboard