function octagon_figure
% OCTAGON_FIGURE:
%
% Generate a binary image of an octagon and detect edges, etc. I used this to debug a
% problem I was having and to provide some figures to illustrate the approach on a slide, 
% but probably won't see much ongoing use.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% scale_space.m
% ggradient.m
% linked_contours.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

EPS = 1e-07;

tscale = 4;
R = 6;
[X,Y] = meshgrid(-10:0.1:10, -10:0.1:10);
[nr, nc] = size(X);

Z = double((abs(X)<R) & (abs(Y)<R) & (abs(X+Y) <= R*sqrt(2)) & (abs(X-Y) <= R*sqrt(2)));

Z = rot90(Z);
Zs = scale_space(Z, tscale);

fig(Z);

figure;
mesh(X,Y,Zs);
GC2;

[G,T, Nm] = ggradient(Zs, 0, 1);
fig(sqrt(G));

figure;
d = 4;
quiver(X(1:d:nr,1:d:nc),Y(1:d:nr,1:d:nc),...
cos(T(1:d:nr,1:d:nc)).*G(1:d:nr,1:d:nc),... 
sin(T(1:d:nr,1:d:nc)).*G(1:d:nr,1:d:nc));

% Second directional derivative
Q = [0, 0, -1, 0, 1, 0, 0]/2;
D = fliplr(Q);
Gy = conv2(D(1,:),      1, G, 'same');
Gx = conv2(     1, D(1,:), G, 'same');
ZC = (Gx .* cos(T) + Gy .* sin(T)) .* (~Nm);  % Added masking by ~Nm
fig(ZC);

% Contours
C = linked_contours(G, T, Nm);
keyboard

