function [s, n, J] = oriented_box_integral(I, x0, y0, w, h, o)
%
% ORIENTED_BOX_INTEGRAL: [s, n, J] = oriented_box_integral(I, x0, y0, w, h, o);
%
% OUTPUT:
% ------
% s  - sum of I values inside oriented box
% n  - number of points inside oriented box
% J  - [optional] mask corresponding to the orient box
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
[nr, nc] = size(I);
EPS = 1e-07;

rect = [-1 1 1 -1 -1; -1 -1 1 1 -1; 1 1 1 1 1];
co = cos(o*pi/180.0);
so = sin(o*pi/180.0);
rot = [co, -so; so, co];
T = [[rot, [x0;y0]]; [0, 0, 1]];
obox = T(1:2,:) * diag([w/2, h/2, 1]) * rect;

E = zeros(4,4); % each row has endpoints for one side of box [u0, u1, v0, v1]
for e = 1:4
  E(e,1) = obox(1,e);
  E(e,2) = obox(1,e+1);
  E(e,3) = obox(2,e);
  E(e,4) = obox(2,e+1);
end

if (nargout > 2)
  J = zeros(nr, nc);
end

y0 = max(floor(min(obox(2,:))), 1); 
y1 = min(ceil(max(obox(2,:))), nr);    
xx = zeros(4,1);

s = 0;
n = 0;
for y = floor(y0):ceil(y1)
  found = 0;
  for e = 1:4
    dv = E(e,4)-E(e,3);
    if (abs(dv) > EPS)
      k = (y-E(e,3))/dv;
      if ((k >= -EPS) & (k <= 1+EPS))
        x = (1-k)*E(e,1) + k*E(e,2);
      else
	x = [];
      end
    else
      x = [];
    end
    if (~isempty(x))
      found = found+1;
      xx(found,1) = x;
    end
  end
  if (found == 2)
    x0 = max( 1, round(min( xx(1:2) )) );
    x1 = min(nc, round(max( xx(1:2) )) );
    if (x1 > x0)
      if (nargout > 2)
        J(y,x0:x1) = 1;
      end
      s = s + sum(I(y,x0:x1));
      n = n+x1-x0+1;
    end
  end
end

%keyboard