function [B, NV] = pds_head(fname)
%
% PDS_HEAD: [B, NV] = pds_head(fname);
%
% INPUT:
% -----
% fname - filename
%
% OUTPUT:
% ------
% NV     - (N x 2) cell array of names and values from text header
% B      - all the bytes from the file including the "label" (text header)
%
% HISTORY:
% -------
% 2005/07/27 (MCB) - Changed to return all the bytes instead of just the bytes
%                      after the "label"
% 2005/07/22 (MCB) - Split this common part out of pds_read.m so I could use for
%                      reading .qub data in addition to images.
%         
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% tokenizer.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

HACK = 0;

fp = fopen(fname, 'r');
if (fp == -1)
  fprintf(1, 'ERROR(pds_head): failed to open file %s\n', fname);
  NV = []; I = [];
  return
end

B = fread(fp, Inf, 'uchar')';  % Read all of the byte into a row vector B
fclose(fp);

lB = length(B);

% Find the four key fields RECORD_TYPE, RECORD_BYTES, FILES_RECORDS, and LABEL_RECORDS
[s, e] = tokenizer(B, ' ');     % split into tokens ignoring whitespace
n_tokens = length(s);
if (n_tokens < 12)
  fprintf(1, 'ERROR(pds_head): tokenizer problems on file %s\n', fname);
  NV = []; I = [];
  return
end

found = [0; 0; 0; 0];
done = 0;
success = 0;
t = 1;
while (~done)
  token0 = char(B(s(t):e(t)));
  token1 = char(B(s(t+1):e(t+1)));
  token2 = char(B(s(t+2):e(t+2)));
  eq = strcmp(token1, '=');
  if (eq == 1)
    if (strcmp(token0, 'RECORD_TYPE') == 1)
      found(1) = 1;
      record_type = token2;
    elseif (strcmp(token0, 'RECORD_BYTES') == 1)
      found(2) = 1;
      record_bytes = str2num(token2);
    elseif (strcmp(token0, 'FILE_RECORDS') == 1)
      found(3) = 1;
      file_records = str2num(token2);
    elseif (strcmp(token0, 'LABEL_RECORDS') == 1)
      found(4) = 1;
      label_records = str2num(token2);
    end
  end

  if (all(found == 1))
    done = 1;
  end

  t = t+1;
  if ((~done) & (t > n_tokens-2))
    done = 1;
    fprintf(1, 'ERROR(pds_head): %d %d %d %d\n', found(1), found(2), found(3), found(4));
    fprintf(1, 'ERROR(pds_head): failed to find all file description fields in %s\n', fname);
    NV = []; I = [];
    return 
  end
end

if (strcmp(record_type, 'FIXED_LENGTH') == 0)
  fprintf(1, 'ERROR(pds_head): only understand FIXED_LENGTH not %s in file %s\n', record_type, fname);
  NV = []; I = [];
  return 
end

ltxt = label_records*record_bytes;
txt = char(B(1:ltxt));
%ldat = lB-ltxt;
%if (ldat > 0)
%  dat = B(ltxt+1:lB);
%end


% Fix stray double quote
fprintf(1, 'HACK = %d\n', HACK);
fprintf(1, 'You can override HACK value at the keyboard statement\n');
fprintf(1, '  16i002tr.qub: HACK = 1;\n');
fprintf(1, '  15i501tr.qub: HACK = 2;\n');
fprintf(1, '  16i002tr_sun.qub: HACK = 3;\n');
fprintf(1, '  15i501tr_sun.qub: HACK = 4;\n');
fprintf(1, '  15i005tr_sun.qub: HACK = 5;\n');
keyboard
if (HACK == 1)
  % 16i002tr.qub
  txt(28165) = ' ';
elseif (HACK == 2)
  % 15i501tr.qub
  txt(28166) = ' ';
elseif (HACK == 3)
  % 16i002tr_sun.qub
  txt(27514) = ' ';
elseif (HACK == 4)
  % 15i501tr_sun.qub
  txt(27517) = ' ';
elseif (HACK == 5)
  % 15i005tr_sun.qub
  txt(27518) = ' ';
end
%------------------------------------------------------------------------------------------
% To faciliatate parsing of quoted strings, vectors, and comments, we create
% a temporary copy of txt in which any white space between dbl quotes, single quotes, 
% parentheses, or between comment characters is replaced.
CR = 13;
NL = 10; 
TAB = 9;

% Double quotes
q = find(txt == '"');
lq = length(q);
qs = [];
if (lq > 0)
  if (mod(lq, 2) == 0)
    qs = q(1:2:lq);
    qe = q(2:2:lq);
  else
    fprintf(1, 'ERROR(pds_head): mismatched double quotes\n');
    NV = []; I = [];
    return
  end
end

% Single quotes
oq = find(txt == char(39));
loq = length(oq);
oqs = [];
if (loq > 0)
  if (mod(loq, 2) == 0)
    oqs = oq(1:2:loq);
    oqe = oq(2:2:loq);
  else
    fprintf(1, 'ERROR(pds_head): mismatched single quotes\n');
    NV = []; I = [];
    return
  end
end


% Parentheses 
ps = find(txt == '('); pe = find(txt == ')');
if (length(ps) ~= length(pe))
  fprintf(1, 'ERROR(pds_head): mismatched parentheses\n');
  NV = []; I = [];
  return
end
if (~all(pe > ps))
  fprintf(1, 'ERROR(pds_head): mismatched parentheses\n');
  NV = []; I = [];
  return
end

% Comment delimiters
cs = find((txt(1:ltxt-1) == '/') & (txt(2:ltxt) == '*'));
ce = find((txt(1:ltxt-1) == '*') & (txt(2:ltxt) == '/'));
if (~isempty(ce))
  ce = ce+1;
end
if (length(cs) ~= length(ce))
  fprintf(1, 'ERROR(pds_head): mismatched comment delimiters\n');
  NV = []; I = [];
  return
end
if (~all(ce > cs))
  fprintf(1, 'ERROR(pds_head): mismatched comment delimiters\n');
  NV = []; I = [];
  return
end

% HERE WE BACKFILL THE WHITESPACE
txt_tmp = txt;
for i = 1:length(qs)
  for j = qs(i):qe(i)
    if ((txt(j) == ' ') | (txt(j) == CR) | (txt(j) == NL) | (txt(j) == TAB))
      txt_tmp(j) = '@';
    end
  end
end

for i = 1:length(oqs)
  for j = oqs(i):oqe(i)
    if ((txt(j) == ' ') | (txt(j) == CR) | (txt(j) == NL) | (txt(j) == TAB))
      txt_tmp(j) = '@';
    end
  end
end

for i = 1:length(ps)
  for j = ps(i):pe(i)
    if ((txt(j) == ' ') | (txt(j) == CR) | (txt(j) == NL) | (txt(j) == TAB))
      txt_tmp(j) = '@';
    end
  end
end

for i = 1:length(cs)
  for j = cs(i):ce(i)
    if ((txt(j) == ' ') | (txt(j) == CR) | (txt(j) == NL) | (txt(j) == TAB))
      txt_tmp(j) = '@';
    end
  end
end

%------------------------------------------------------------------------------------------
% HERE WE GET ALL THE NAME-VALUE PAIRS OUT OF THE TXT
%------------------------------------------------------------------------------------------

[s, e] = tokenizer(txt_tmp, ' ');     % split into tokens ignoring whitespace
n_tokens = length(s);
NVtmp = cell(n_tokens, 2);

done = 0;
success = 0;
t = 1;
k = 0;
looking_for = 0;  % 0 = Name, 1 = Equals, 2 = value
while (~done)
  is_comment = 0;
  token = txt(s(t):e(t));
  L = e(t)-s(t)+1;

  if (L >= 4)
    if (token([1,2,L-1,L]) == '/**/')
      is_comment = 1;
    end
  end

  if (~is_comment)
    if (looking_for == 0)
      if (strcmp(token, 'END') == 1)
        done = 1;
      else
        k = k+1;
        NVtmp{k,1} = token;
        looking_for = 1;
      end
    elseif (looking_for == 1)
      if (token == '=')
        looking_for = 2;
      else
        keyboard
        fprintf(1, 'ERROR (pds_head): expecting =, found %s\n', token);
        NV = []; I = [];
        return
      end
    elseif (looking_for == 2)
      NVtmp{k,2} = token;
      looking_for = 0;
    end 
  end

  t = t+1;
  if (t > n_tokens)
    done = 1;
  end
end


NV = cell(k,2);
for i=1:k
  for j = 1:2
    NV{i,j} = NVtmp{i,j};
  end
end
