function [p,f, x] = pfx(fname, path_separator, print_verify)
% 
% PFX: [p, f, x] = pfx(fname, print_verify);
%
% Identify path, file, and extension portion of string fname.
% The three outputs indicate where each portion starts. If
% there is no path, p = 0, else p = 1. If there is no extension
% x = L+1, where L is the string length.
%
% INPUT:
% -----
% fname          - string
% path_separator - string (use '/' for unix (def), and '\' for windows)
% print_verify   - flag (0=def= do nothing, 1= print out the prefix, filename, and suffix)
%
% OUTPUT:
% ------
% p - starting position of path portion; if no path then p=0.
% f - starting position of file portion
% x - starting position of extension (rightmost dot); 
%       if none, then x=L+1, where L is string length
%
% NOTE:
% ----
% Without input arg 2, we assume unix style separator in path (forward slash).
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 3)
  print_verify = 0;
end
if (nargin < 2)
  path_separator = '/';
end

L = length(fname);

% Find rightmost slash
p_end = find(fname == path_separator);
if (~isempty(p_end))
  p_end = max(p_end);
else
  p_end = 0;
end

% Find rightmost period
x_start = find(fname == '.');
if (~isempty(x_start))
  x_start = max(x_start);
else
  x_start = 0;
end

if ((p_end ~= 0) & (x_start ~= 0))
  p = 1;
  f = p_end+1;
  x = x_start;
  if (x <= f)
    x = L+1;
  end
elseif ((p_end == 0) & (x_start ~= 0))
  p = 0;
  f = 1;
  x = x_start;
  if (x <= f)
    x = L+1;
  end
elseif ((p_end ~= 0) & (x_start == 0))
  p = 1;
  f = p_end+1;
  x = L+1;
else
  p = 0;
  f = 1;
  x = L+1;
end


if (print_verify == 1)
  fprintf(1, 'prefix = |');
  if (p>=1)
    fprintf(1,'%s', fname(p:f-1));
  end;
  fprintf('|\n');

  fprintf(1, 'file   = |'); 
  if (x>=1)
    fprintf(1,'%s',fname(f:x-1));
  end

  fprintf('|\n');
  fprintf(1,'suffix = |');
  if(x<=L),
    fprintf(1,'%s',fname(x:L));
  end;
  fprintf(1,'|\n');
end
