function p = phi(z, mu, sigma)
%
% PHI: p = phi(z, mu, sigma);
%
% Evaluate probability that a Gaussian R.V. with mean mu, std dev sigma is
%   less than z
%
% INPUT:
% -----
% z     - scalar;
% mu    - scalar; mean of Gaussian
% sigma - scalar; standard deviation of Gaussian
%
% OUTPUT:
% ------
% p  - scalar; probability that Gaussian R.V. with mean mu and standard dev sigma is < z.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin <= 1)
  mu = 0.0;
  sigma = 1.0;
end

zz = (z - mu) / sigma;

p = 0.5 + 0.5 * erf(zz/sqrt(2));
