function plot_ellipse(mux, muy, Sxx, Sxy, Syy, mag, col, lth)
%
% PLOT_ELLISPE: plot_ellipse(mux, muy, Sxx, Sxy, Syy, mag, col, lth);
%
% Plots ellipse satisfying the equation:
%
% [x-mux, y-muy] * inv([Sxx, Sxy; Sxy, Syy]) * [x-mux; y-muy] = mag^2;
%
% INPUT:
% -----
% mux   - x-coord of ellipse center
% muy   - y-coord of ellipse center
% Sxx   - these three parameters define the covariance matrix 
% Sxy       associated with the ellipse.
% Sxy
% mag   - magnification
% col   - color code, e.g., 'r'
% lth   - line thickness (def=1)
%
% OUTPUT:
% ------
% Draws ellipse on current plot (be sure to turn hold 'on') first.
%
% NOTE: For degenerate cases, we just plot an 'x' symbol at the
% ellipse center.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
if(nargin < 8)
  lth = 1;
end

EPS = 1e-07;
theta = 2 * pi * [0:0.01:1];

d = sqrt(4*Sxy^2+(Sxx-Syy)^2);
if (Sxx*Syy-Sxy*Sxy < EPS)
  plot(mux, muy, [col,'x'], 'Linewidth', lth);    
elseif (Sxx < EPS)
  plot(mux, muy, [col,'x'], 'Linewidth', lth);  
elseif (Syy < EPS)
  plot(mux, muy, [col,'x'], 'Linewidth', lth);  
elseif (d < 1e-07)
  % Circle
  r = mag*sqrt(Sxx);
  plot(mux+r*cos(theta), muy+r*sin(theta), 'Color', col, 'Linewidth', lth);
else
  s2t = 2*Sxy/d; c2t = (Sxx-Syy)/d;
  o = atan2(s2t, c2t)/2;
  w = mag * sqrt(0.5*(Sxx+Syy) + 0.5*d);
  h = mag * sqrt(0.5*(Sxx+Syy) - 0.5*d);
  rot = [cos(o) -sin(o); sin(o), cos(o)];
  ell = rot * [w * cos(theta); h * sin(theta)];
  plot(mux+ell(1,:), muy+ell(2,:), 'Color', col, 'Linewidth', lth);
end
