function plot_ellipse_many(M, mag, col, lth)
%
% PLOT_ELLISPE_many: plot_ellipse_many(M, mag, col, lth);
%
% Plots ellipses satisfying the equation:
%
% [x-mux, y-muy] * inv([Sxx, Sxy; Sxy, Syy]) * [x-mux; y-muy] = mag^2;
%
% where mux = M(i,1), muy = M(i,2), Sxx = M(i,3), Sxy = M(i,4), Syy = M(i,5)
%
% INPUT:
% -----
% M     - (n_ellipses X 5)
% mag   - magnification
% col   - color code, e.g., 'r'
% lth   - line thickness (def=1)
%
% OUTPUT:
% ------
% Draws ellipse on current plot (be sure to turn hold 'on') first.
%
% NOTE: For degenerate cases, we just plot an 'x' symbol at the
% ellipse center.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% plot_ellipse.m
% hon.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
if(nargin < 4)
  lth = 1;
end

[mr, mc] = size(M);
if ((mr == 5) & (mc == 1))
  % single ellipse given as column vector -> change to row
  M = M';
end

if (size(col,1) == 1)
  % single color code or RGB color for all
  for i=1:mr
    keyboard
    plot_ellipse(M(i,1), M(i,2), M(i,3), M(i,4), M(i,5), mag, col, lth);
    hon;
  end
elseif ((size(col,1) >= mr) & (size(col,2) == 3))
  % RGB color for each
  for i=1:mr
    plot_ellipse(M(i,1), M(i,2), M(i,3), M(i,4), M(i,5), mag, col(i,:), lth);
    hon;
  end
else
  fprintf(1, 'ERROR (plot_ellipse_many): bad color specification\n');
  return
end  
