function plot_graph(V, E, cols, lwidth)
%
% PLOT_GRAPH: plot_graph(V, E, cols, lwidth)
%
% INPUT:
% -----
% V - (N x 2) matrix of vertices in 2D
% E - OPT1: (N x N) binary matrix of edges
%   - OPT2: (M X 2) matrix of links between nodes
% cols - color, e.g., 'b'
% lwidth - linewidth (default = 1)
%
% OUTPUT:
% ------
% Plot in 2D of the graph
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% hon.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 4)
  lwidth = 1;
end
if (nargin < 3)
  cols = 'b';
end

[vr, vc] = size(V);
[er, ec] = size(E);
if (ec == 2)
  links = 1;
else
  links = 0;
end

if (links == 0)
  if ((vc ~= 2) | (er ~= vr) | (ec ~= vr))
    fprintf(1, 'ERROR (plot_graph): dimensions dont match: V (%d x %d), E (%d x %d)\n', vr, vc, er, ec);
    return;
  end

  h = plot(V(:,1), V(:,2), [cols(1:1),'.'],'Markersize', 24);
  hon;

  % Assume E is symmetric
  for i = 1:vr-1
    for j = i+1:vr
      if (E(i,j) == 1)
        h = plot([V(i,1), V(j,1)], [V(i,2), V(j,2)]);
        set(h, 'Color', cols, 'Linewidth', lwidth);      
      end
    end
  end
else
  h = plot(V(:,1), V(:,2), [cols(1:1),'.'],'Markersize',24);
  hon;

  for m = 1:er
    i = E(m,1);
    j = E(m,2);
    h = plot([V(i,1), V(j,1)], [V(i,2), V(j,2)]);
    set(h, 'Color', cols, 'Linewidth', lwidth);      
  end
end
