function plot_homogeneous_ellipse(A, mag, col, lth)
%
% PLOT_HOMOGENEOUS_ELLISPE: plot_homogeneous_ellipse(A, mag, col, lth);
%
% Plots ellipse satisfying the equation:
%
% [x, y, 1] * A * [x; y; 1] = mag^2;
%
% INPUT:
% -----
% A - (3 X 3) matrix; 
%       A(1:2,1:2) = [Sxx, Sxy; Sxy, Syy]^{-1}
%       A(1:2,3)   = -A(1:2,1:2) * [mux; muy];
%       A(3,1:2)   = -[mux, muy] * A(1:2,1:2);
%       A(3,3)     = [mux, muy] * A(1:2,1:2) * [mux; muy];
%     where
%       mux   - x-coord of ellipse center
%       muy   - y-coord of ellipse center
%       Sxx   - these three parameters define the covariance matrix 
%       Sxy       associated with the ellipse.
%       Sxy
% mag   - magnification
% col   - color code, e.g., 'r'
% lth   - line thickness (def=1)
%
% OUTPUT:
% ------
% Draws ellipse on current plot (be sure to turn hold 'on') first.
%
% NOTE: For degenerate cases, we just plot an 'x' symbol at the
% ellipse center.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
if(nargin < 4)
  lth = 1;
end
EPS = 1e-05;
if (abs(det(A(1:2,1:2))) > EPS)
  S = inv(A(1:2,1:2));
  mu = -S * A(1:2,3);
  plot_ellipse(mu(1), mu(2), S(1,1), S(1,2), S(2,2), mag, col, lth);
end
