function plot_oriented_rect(x0, y0, l, w, theta, col, lth)
%
% PLOT_ORIENTED_RECT: plot_oriented_rect(x0, y0, l, w, theta, col, lth);
%
% Plots an oriented rectangle
%
% INPUT:
% -----
% x0, y0, l, w, theta - oriented rectangle specification (theta in degrees)
% col   - color code, e.g., 'r'
% lth   - line thickness (def=1)
%
% OUTPUT:
% ------
% Draws rectangle on current plot (be sure to turn hold 'on') first.
%
% NOTE: Theta is measured clockwise from horizontal
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if(nargin < 7)
  lth = 1;
end

cth = cos(theta*pi/180);
sth = sin(theta*pi/180);
ll = l/2;
ww = w/2;
x = x0 + ll*[1,1,-1,-1,1] * cth + ww * [-1,1,1,-1,-1] * -sth;
y = y0 + ll*[1,1,-1,-1,1] * sth + ww * [-1,1,1,-1,-1] * cth;;
plot(x,y, col, 'Linewidth', lth);

