function plot_progeny(t, tgt, c, TE_master, LL_master)
%
% PLOT_PROGENY: plot_progeny(t, tgt, c, TE_master, LL_master);
%
% Construct plot with lines from parent point to child(ren) points. Used in constructing
% area vs time plot (see flower_5_area_vs_time.m).
%
% INPUT:
% -----
% t         - start frame
% tgt       - lineage label
% c         - (1 x 3) color vector
% TE_master - (n x 10) matrix; col1 = time, col2 = x, col3 = y, col4 = z
%               col 5 : col 10 = ellipse moments.
% LL_master - (n x 1) cell array with lineage (tree) labels
%
% OUTPUT:
% ------
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% lineage_label_info.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

fade = 1.0;

xy_scale = [1.8; 0.9*ones(7,1); 1.27*ones(7,1); 1.8; 2.54];
z_scale  = 2;

% Time indices for which we have data
tt = [1:9, 11:15,17]';
n = find(tt == t);
if (isempty(n))
  fprintf(1, 'ERROR (plot_progeny): bad time not in tt\n');
  return
end

Eall = icluster_ellipse_params(TE_master(:,5:10));
Aall = pi * Eall(:,4) .* Eall(:,5);

prev = [NaN, NaN];
done = 0;
while (~done)
  % See if target exists at time tt(n)
  I = lineage_label_info(tt(n), tgt, TE_master(:,1), LL_master, 0);
  rho = I{3,1};
  if (~isempty(rho))
    % target exists
    fac = xy_scale(tt(n),1).^2;    
    A = Aall(rho(1), 1) * fac;
    if (~isnan(prev(1,1)))
      plot([prev(1,1), tt(n)], [prev(1,2), A], 'Color', c);
    end
    prev = [tt(n), A];
    n = n+1;
  else
    done = 1; % did not find target
  end
end

% Check whether any children of tgt exist at time tt(n)
rho = I{4,1};
if (~isempty(rho))
  for i=1:length(rho)
    fac = xy_scale(tt(n),1).^2;    
    A = Aall(rho(i), 1) * fac;

    % plot line from last parent point to child point
    if (~isnan(prev(1,1)))
      plot([prev(1,1), tt(n)], [prev(1,2), A], 'Color', fade*c);
      plot(prev(1,1), prev(1,2), '.', 'Markersize', 24, 'Linewidth', 2, 'Color', c);      
    end
    plot_progeny(tt(n), LL_master{rho(i),1}, fade*c, TE_master, LL_master)
  end
end
