function [A, E] = polyhedrons_from_voxelized(V, oid)
%
% POLYHEDRONS_FROM_VOXELIZED: [A, E] = polyhedrons_from_voxelized(V, oid);
%
% Given a voxelized representation of a set of compartments, derive a polyhedral
% representation.The method requires improvements to work for concave compartments or
% comparments that have multiple plaanr facets agaisnt the background.
%
% INPUT:
% -----
% V   - (nx X ny X nz) voxelization; each voxel contains object id (or 0=background)
% oid - single object id number to process
%
% OUTPUT:
% ------
% A  - (n_planes X 4) - matrix in which each row is a separating plane
% E  - (n_planes X 1) - error incurred for each plane fit
%
% NOTES:
% -----
% It looks like this function was originally written to use RANSAC method
% but then adapted to use linear SVM; however, the output variables were
% not changed to reflect SVM results.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
n_cells = max(max(max(V)));
A = zeros(n_cells+1, 4);
E = Inf * ones(n_cells+1, 1);

[nx, ny, nz] = size(V);

Q = cell(n_cells+1,1);
for n = 1:n_cells+1
  Q{n,1} = [];
end

for x = 1:nx
  for y = 1:ny
    for z = 1:nz
      l1 = V(x,y,z);
      if (l1 ~= 0)
        Q{l1,1} = [Q{l1,1}; [x,y,z]];
      end
    end
  end
end

obase = '/proj/og1/biology/aroeder/tests/obj';
%for n = 1:n_cells
%  p = Q{n,1};
%  vwrite([obase, int2str(n), '_pts'], p, 5);
%end

P = cell(n_cells+1,1);
for n = 1:n_cells+1
  P{n,1} = [];
end

for x = 1:nx
  for y = 1:ny
    for z = 1:nz
      if (V(x,y,z) == oid)
        for i=-1:1
	  for j=-1:1
	    for k=-1:1
	      if (abs(i) + abs(j) + abs(k) > 0)
 	        l2 = V(x+i, y+j, z+k);
		if (l2 == 0)
		  l2 = n_cells+1;
		end
	        P{l2, 1} = [P{l2,1}; [x+i/2, y+j/2, z+k/2]];
              end
	    end
	  end
	end
      end
    end
  end
end

for n = 1:n_cells+1
  if (n ~= oid)
    p = P{n,1};
    if (size(p,1) >= 3)
      [w, t, r, e, s, t_best, r_best, e_best] = lqs2([p, ones(size(p,1),1)], 0.5);
      A(n,:) = t_best'/norm(t_best(1:3));
      E(n,1) = e_best;
    end
  end
end

Ar = A(~isinf(E),:);

ind = find(~isinf(E));
N = length(ind);
xbase = '/home/burl/checkout/burlcode/src/programs/train_svm/';
on1 = [obase, int2str(oid), '_pts'];
B = zeros(N, 4);
for l = 1:N
  % Train an SVM to discriminate between oid and ind(l)
  on2 = [obase, int2str(ind(l)), '_pts'];  
  svm_name = [obase, 'obj', int2str(oid), '_vs_obj', int2str(ind(l)), '.svm'];
  cmd = ['!', xbase, 'x_train_svm -P ', on1, ' -N ', on2, ' -format 1 -linear -c_svm 100 -o ', svm_name];
  eval(cmd);
  
  % Read result back in
  [gamma, alpha, svecs, b] = read_libsvm(svm_name);
  tvec = [sum((alpha*ones(1,3)) .* svecs)'; -b]; 
  tvec = tvec./norm(tvec(1:3));
  B(l,:) = tvec';
end  

keyboard
