function C = randcol(n, minave)
% RANDCOL: C = randcol(n, minave);
%
% Generate n random RGB colors; if desired, the argument minave can be specified
% to limit the colors to RGB triples in which (R+G+B)/3 > minave.
%
% INPUT:
% -----
% n      - number of random colors to produce
% minave - optional scalar; limit RGB triples to those in which (R+G+B)/3 > minave
%
% OUTPUT:
% ------
% C - (n x 3) matrix; each row is an RGB triple
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 2)
  minave = 0;
end
if (minave >= 1)
  fprintf(1, 'WARNING (randcol): minave must be in (0,1)\n');
  minave = 0;
end

minsum = 3*minave;

C = zeros(n, 3);

for i = 1:n
  done = 0;
  while (~done)
    c = rand(1,3);
    if (sum(c) >= minsum)
      C(i,:) = c;
      done = 1;
    end
  end
end