function raw_stack_avi(oname)
%
% RAW_STACK_AVI: raw_stack_avi(oname);
%
% Generate an avi movie from a sequence of figure frames. This m-file is hard-wired
% to generate a raw from one of Adrienne's CSLM stacks.
%
% INPUT:
% -----
% oname - name for output movie
%
% OUTPUT:
% ------
% avi movie file written into oname
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% construct_fname.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
if (nargin < 1)
  oname = '/proj/og1/biology/aroeder/tests/raw_stack.avi';
end

ibase = '/proj/og1/biology/aroeder/images_to_segment/ML1-2XCFP-N7_FM4-64/74_flower/pAR107_74_fl_1B_stack/pAR107_74_1B';
isuff = '.tif';
fwidth = 3;
f0 = 0;
f1 = 47;

f=figure;
set(f,'DoubleBuffer','on');
set(gca, 'NextPlot','replace','Visible','off')
mov = avifile(oname)
for f = f0:f1
  fname = construct_fname(ibase, isuff, f, fwidth);
  I = imread(fname);
  J = double(I);
  
  % Apply nonlinear scaling to each channel to improve visibility
  J(:,:,1) = sqrt(J(:,:,1))/16;
  J(:,:,2) = sqrt(J(:,:,2))/16;
  J(:,:,3) = sqrt(J(:,:,3))/16;  
  
  image(J);
  title(int2str(f), 'Fontsize', 18);
  F = getframe(gca);
  mov = addframe(mov,F);
end
mov = close(mov);
