function P = read_polyhedrons(fname)
%
% READ_POLYHEDRONS: P = read_polyhedrons(fname);
% 
% Read in one of Bruce Shapiro's polyhedron files, which describes a set of 
% polyhedrons in facets form.
%
% INPUT:
% -----
% fname - input filename
%
% OUTPUT:
% ------
% P - (N x 1) cell array, where N is the number of biological cells
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

fp = fopen(fname, 'r');
if (fp == -1)
  fprintf(1, 'ERROR (read_polyhedrons): failed to open %s\n', fname);
  P = [];
  return
end

line = fgetl(fp);
n_cells = str2num(line);

P = cell(n_cells, 1);

for n = 1:n_cells
  line = fgetl(fp);
  n_facets = str2num(line);
  F = cell(n_facets, 1);
  for f = 1:n_facets
    line = fgetl(fp);
    n_vertices = str2num(line);
    V = zeros(n_vertices, 3);
    for v = 1:n_vertices
      line = fgetl(fp);
      a = sscanf(line, '%f', 3);
      V(v,1:3) = a';
    end
    F{f,1} = V;
  end
  P{n,1} = F;
end

fclose(fp);
