function Q = remove_appendages(Z, kappa)
%
% REMOVE_APPENDAGES: Q = remove_appendages(Z, kappa);
%
% This function uses morphological filtering operations to remove thin white appendages
% from a binary image. Appendages that are of width < 2*kappa+1 are removed.
%
% INPUT:
% -----
% Z      - binary-valued image
% kappa  - "radius" of square structuring element
%
% OUTPUT:
% ------
% Q      - binary-valued image
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

T = ones(2*kappa+1, 2*kappa+1);
Z = (Z >= 0.5); % binarize

C = conv2((1-Z), T, 'same'); % complement and convolve with T 
C = (C >= 0.5); % binarize
Q = conv2((1-C), T, 'same'); % complement and convolve with T
Q = (Q >= 0.5); % binarize
