function zval = retrieve_z(x, y, Z, w)
%
% RETRIEVE_Z: zval = retrieve_z(x, y, Z, w);
%
% Get a smoothed zval at location (x,y) by taking median of Z values over a (w x w) window
% centered at this location.
%
% INPUT:
% -----
% x - x-coordinate of point at which we wish to know z-value
% y - y-coordinate of point at which we wish to know z-value
% Z - image fo Z-values
% w - window over which to choose median value
%
% OUTPUT:
% ------
% zval -
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% half_width.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 4)
  w = 5;
end

[zr, zc] = size(Z);
[wm, wp] = half_width(w);

xx = round(x);
yy = round(y);

cnt = 0;
pix = zeros(w*w,1);
for ii = -wm:wp
  i = yy+ii;
  for jj = -wm:wp
    j = xx+jj;
    if ((i >= 1) & (i <= zr) & (j>=1) & (j <= zc))
      cnt = cnt+1;
      pix(cnt,1) = Z(i,j);
    end
  end
end
if (cnt > 0)
  zval = median(pix(1:cnt,1));
else
  zval = NaN;
end
