function J = rgb_resize(I, M, method)
%
% RGB_RESIZE: J = rgb_resize(I, M, method);
%
% INPUT:
% -----
% I      - (ir X ic X 3) RGB image
% M      - scalar or 2 element vector. 
%            If scalar, [jr, jc] = M * [ir, ic] where [ir, ic] is the size of
%              the input image and [jr, jc] is the size of the output image.
%            If vector, [jr, jc] = M.
%
% method - string specifying the interpolation method. Available choices are 'nearest',
%          'bilinear', and 'bicubic'.
%
% OUTPUT:
% ------
% J      - (jr X jc X 3) resized version of I.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% myresize.m
% scale.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 3)
  method = 'bilinear';
end

% Extract each band
n_bands = size(I,3);
for k = 1:n_bands
  Ik = myresize(double(I(:,:,k)), M, method);
  if (k == 1)
    [jr, jc] = size(Ik);
    J = zeros(jr, jc, n_bands);
  end
  J(:,:,k) = scale(Ik, 0, 255, 0, 255);
end
