function L = scale_space(I,tvec)
%
% SCALE_SPACE: L = scale_space(I, tvec);
%
% Compute the Lindeberg scale-space representation of an image I at
% the set of scales specified in t.
%
% INPUT:
% -----
% I     - (nr X nc) image
% tvec  - (nt X 1) vector of scales or scalar for a single scale
%
% OUTPUT:
% ------
% L - (nr X nc X nt) cube (if nt > 1)
%   - (nr X nc) image (if nt == 1)
%
% HISTORY:
% -------
% 2007/05/22 (MCB) - Added ceil in calculation of nu_max to insure 
%                      kernel length is odd.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

[nr, nc] = size(I);
nt = length(tvec);

if (nt == 1)
  L = zeros(nr, nc);
else
  L = zeros(nr, nc, nt);
end

delta_nu = 1;
nu_max = ceil(3*sqrt(max(tvec)));
nu = (-nu_max : delta_nu : nu_max)';

for k = 1:nt
  t = tvec(k);
  h = exp(-t) * besseli(abs(nu), t);
  if (nt > 1)
    L(:,:, k) = conv2(h', h, I, 'same');
  else
    L = conv2(h', h, I, 'same');    
  end
end