function L = segment_pears(I)
%
% SEGMENT_PEARS: L = segment_pears(I);
%
% INPUT:
% -----
% I - grayscale image
%
% OUTPUT:
% ------
%
%
% NOTE:
% ----
% See http://www.mathworks.com/products/demos/image/watershed/ipexwatershed.html
% This function uses various mathematical morphology functions from image processing toolbox
%
% >> which watershed
% /dsw/matlab-7.2_64/toolbox/images/images/watershed.m
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% ggradient.m
% scale.m
% icluster_display.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
if (nargin < 1)
  RGB = imread('/proj/og1/biology/aroeder/data/ipexwatershed_img_02_01.png');
  G = rgb2gray(RGB);
  I = G(60:540,110:835);
end

radius1 = 20;
radius2 = 5;
%radius1 = 3;
%radius2 = 3;

[M,T,NM] = ggradient(I,0,1);
MM = round(scale(M.*NM,-Inf,Inf,0,255));

se = strel('disk', radius1);
Io = imopen(I, se);
Ie = imerode(I, se);
Iobr = imreconstruct(Ie, I);
Iobrd = imdilate(Iobr,se);
Iobrcbr = imreconstruct(imcomplement(Iobrd), imcomplement(Iobr));
Iobrcbr = imcomplement(Iobrcbr);
fgm = imregionalmax(Iobrcbr);

se2 = strel(ones(radius2, radius2));
fgm2 = imclose(fgm, se2);
fgm3 = imerode(fgm2, se2);
fgm4 = bwareaopen(fgm3, radius1);

bw = im2bw(Iobrcbr, graythresh(Iobrcbr));
D = bwdist(bw);
DL = watershed(D);
bgm = (DL == 0);

gradmag2 = imimposemin(MM, bgm|fgm4);
gradmag2(isinf(gradmag2)) = 0;
L = watershed(gradmag2);
maxL = max(max(L));
C = randcol(1+max(max(L)), 0.3);
icluster_display(L, C);

% Fancy display
Lrgb = label2rgb(L, C);
fig(double(I)+(L==0)*16);
hon;
himage = imshow(Lrgb);
set(himage,'AlphaData', 0.3);

% image with edge points in red
fig(I);hon;[i,j] = find(L==0);plot(j,i, 'r.', 'Markersize', 2)

keyboard
