function G = slice_compartments(fname, dz)
%
% SLICE_COMPARTMENTS: G = slice_compartments(fname, dz);
%
% Compute set of 2D slices at dz increments through a set of polyhedrons in facet form.
%
% INPUT:
% -----
% fname - filename for set of polyhedrons in facet form (e.g., from Bruce)
%
% OUTPUT:
% ------
% G     - set of compartments for each slice through the set of polyhedrons
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% read_polyhedrons.m
% randcol.m
% facets_to_triangulated.m
% sample_count.m
% slice_triangulated.m
% graph_from_segments.m
% compartments_from_graph.m
% arcresamp.m
% curvature.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

% fname = '/proj/og1/biology/aroeder/data/files-for-mike-burl/f2.txt';
Pf = read_polyhedrons(fname);
C = randcol(size(Pf,1),0.3);
[V,T,C,L] = facets_to_triangulated(Pf, C);

% Determine range of coordinates
vmin = min(V);
vmax = max(V);
zmin = vmin(3);
zmax = vmax(3);

n_levels = sample_count(zmin, dz, zmax);
G = cell(n_levels, 1);
l = 0;
for z = zmin:dz:zmax
  l = l+1;
  P = [0;0;1;-z];
  S_master = slice_triangulated(P, V, T, C, L);
  seg  = S_master(:,[1,2,4,5]); % just need x and y coordinates 
  qseg = floor(seg*1000)/1000;  % quantize segment endpoints onto 0.001 grid
  [vrt, edg] = graph_from_segments(qseg);
  Pset = compartments_from_graph(vrt, edg);
  keyboard
  % Eliminate the perimeter ("background") compartment
  n = size(Pset, 1);
  Pset_fg = cell(n-1,1);
  cnt = 0;
  for i = 1:n
    N = Pset{i,1};
    xy = vrt([N; N(1)],:);
    e = arcresamp(xy, 1);
    K = curvature(e, 1, 3);
    if (sum(K) > 0)
      cnt = cnt+1;
      Pset_fg{cnt,1} = xy;
    else
      fprintf(1, 'l = %d, eliminating perimeter compartment %d of %d\n', l, i, n);
    end
  end
  G{l,1} = Pset_fg;
end
