function S_master = slice_triangulated(P, V, T, C, L)
%
% SLICE_TRIANGULATED: S_master = slice_triangulated(P, V, T, C, L);
%
% Given a triangulated hypersurface, cut with a plane to produce
% a set of segments.
%
% INPUT:
% -----
% P - (4 X 1) vector describing plane in homogeneous coordinates
% V - (n_vertices X 3) matrix of vertices in the triangulated hypersurface
% T - (n_triangles X 3) matrix of indices into V; each row defines a triangle
% C - (n_triangles X 3) matrix of RGB color spec for each triangle
% L - (n_triangles X 1) vector with object ID label for each triangle
%
% OUTPUT:
% ------
% S_master - (n_segments X 6); each row has the form  [x0, y0, z0, x1, y1, z1]
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% intersect_plane_triangle.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

S_master = [];
for t = 1: size(T,1)
  S = intersect_plane_triangle( P, V(T(t,:),:) );
  if (size(S,1) == 1)
    S_master = [S_master; S(1,:), S(1,:)];  % intersection in point
  elseif (size(S,1) == 2)
    S_master = [S_master; S(1,:), S(2,:)];  % intersect in line segment
  elseif (size(S,1) == 3)
    S_master = [S_master; [S(1,:), S(2,:)]; [S(2,:), S(3,:)]; [S(3,:), S(1,:)]];  % intersect in triangle
  end
end

