function S_master = slice_voronoi(xyz)
%
% SLICE_VORONOI: S_master = slice_voronoi(xyz)
%
% Construct 3D Voronoi compartments based on 3D nucelus positions, then make slices through
% the 3D structure at different heights.
%
% INPUT:
% -----
% xyz - nuclei centroids in 3D 
%
% OUTPUT:
% ------
% S_master - set of segments
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% construct_fname.m
% slice_triangulated.m
% vread.m
% fig.m
% hon.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

nbase = '/proj/og1/biology/mheisler/data/oct_eric/subtracted/nuclei_sqrt_median/nuc';
nsuff = '.sdt';
ibase = '/proj/og1/biology/mheisler/data/oct_eric/unsubtracted/membranes/mem';
isuff = '.tif';
f0 = 0;
f1 = 29;
fwidth = 3;

if (nargin < 1)
  xyz = load('/proj/og1/biology/mheisler/data/oct_eric/tigran_centroids.dat');
end

% Construct 3D Voronoi cells from nuclei centers
[V_vor, C_vor] = voronoin(xyz);

% Compute convex hull of cells
V_master = [];
T_master = [];
C_master = [];
L_master = [];
n_cells = size(C_vor,1);
kk = 0;
for k = 1:n_cells
  X = V_vor(C_vor{k,1},:); % X is n_points X d (= vertices of voronoi cell k)
  if (~any( isinf(X(:,1)) ))
    kk = kk+1;
%    fprintf(1, '%d ', k);
%    if (k == 197)
%      keyboard
%    end
    T = convhulln(X, {'QJ'}); % K will be n_facets X d
    offset = size(V_master,1);
    V_master = [V_master; X];
    T_master = [T_master; T+offset];
    n_triangles = size(T,1);
    C_master = [C_master; ones(n_triangles,1) * randcol(1, 0.5)];
    L_master = [L_master; kk * ones(n_triangles, 1)];
  end
end


% Make horizontal slices
for f = f0:f1
%  iname = construct_fname(ibase, isuff, f, fwidth);
%  I = imread(iname);
%  fig(sqrt(double(I)));
  nname = construct_fname(nbase, nsuff, f, fwidth);
  I = vread(nname);
  fig(I);
  hon;
  
  P = [0; 0; 1; -f];
  S_master = slice_triangulated(P, V_master, T_master, C_master, L_master);
  for i = 1:size(S_master,1)
    plot(S_master(i,[1,4]), S_master(i,[2,5]), 'r', 'Linewidth', 2);
  end
  pause(1);
  keyboard
end
