function [L_master, C_master, Cset_master] = smr1_nuclei
%
% SMR1_NUCLEI: [L_master, C_master, Cset_master] = smr1_nuclei();
%
% Apply the sepal_nuclei function to the set of smr1 images (identified in the file ilist.txt). 
% Collect the results in the _master cell arrays. The output from this program is considered
% to be the "REV0" product. After manual correction with segmentation_editor.m, the result
% is considered to be a "REV1" product.
%
% INPUT:
% -----
% none (input image filenames are loaded into smr1_cell below)
%
% OUTPUT:
% ------
% L_master    - (n_images X 1) cell array; cell i contains the label image for image i. 
% C_master    - (n_images X 1) cell array; cell i contains (nobj X 3) RGB color matrix for image i.
% Cset_master - (n_images X 1) cell array; cell i contains contour set (a nobj x 1) cell array)
%                  for image i. Each cell in the contour set is a (n_pts X 2) matrix with the
%                  coordinates of vertices along the contour.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% sepal_nuclei.m
% icluster_contours.m
% plot_edges.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
DISPLAY_FLAG = 0; % Do not display figures
thr = 40;

smr1_cell = load_lines('/proj/og1/biology/aroeder/data/nuclear_extraction/smr1/ilist.txt');
N = size(smr1_cell,1);

L_master = cell(N,1);
C_master = cell(N,1);
Cset_master = cell(N,1);
for n=1:N
  [Lfinal, Cfinal] = sepal_nuclei(smr1_cell{n,1}, thr); 
  Cset = icluster_contours(Lfinal, size(Cfinal, 1));
  
  L_master{n,1} = Lfinal;
  C_master{n,1} = Cfinal;
  Cset_master{n,1} = Cset;
  
  if (DISPLAY_FLAG == 1)
    I = imread(smr1_cell{n,1});
    figure;image(I);hon;
    plot_edges(Cset, 1, Cfinal, 1);
  end
end
keyboard
