function [V, D] = symeig2(M)
%
% SYMEIG2: [V,D] = symeig2(M);
%
% Compute eigenvalues and eigenvectors of a symmetric 2X2 matrix M
%
% INPUT:
% -----
% M  - (2 X 2) symmetric matrix 
%
% OUTPUT:
% ------
% V  - (2 X 2) matrix of eigenvectors; each column is normalized to unit length
% D  - (2 X 2) diagonal matrix; D(1,1) < D(2,2)
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

a = M(1,1);
b = 2*M(1,2);
c = M(2,2);
e = a-c;
d = sqrt(b.^2 + e.^2);

% Eigenvalues
lambda_p = (a + c + d)/2;
lambda_m = (a + c - d)/2;
D = diag([lambda_m, lambda_p]);

% Eigenvectors
if (b ~= 0)
  V = [-sign(b)*sqrt(d-e), sign(b)*sqrt(d+e); sqrt(d+e), sqrt(d-e)];
else
  if (a < c)
    V = [1, 0; 0, 1];
  else
    V = [0, 1; 1, 0];
  end  
end
V(:,1) = V(:,1)/norm(V(:,1));
V(:,2) = V(:,2)/norm(V(:,2));

