function [s, e] = tokenizer(line, sep_chars)
%
% TOKENIZER: [s, e] = tokenizer(line, sep_chars);
%
% Separate a line of text into "tokens" (sequences of characters not broken up
% by white space or one of the special sep_chars.
%
% INPUT:
% -----
% line      - line of text
% sep_chars - set of characters that can be use to separate tokens
%
% OUTPUT: 
% ------
% s - indices of word-starting characters within line
% e - indices of word-ending characters within line
%
% HISTORY:
% -------
% 2005/07/22 (MCB) - Tab character was missing from white space chars
% 2001/12/28 (MCB) - Changed to take sep_chars. Now you must
% specifically specify a comma if you want to include it as a separator.
%
% NOTE: 
% ----
% Doesn't properly deal with ignoring separators in quoted strings. See also backfill.m.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

if (nargin < 2)
  sep_chars = [];
end
  
CR = 13; % carriage return
NL = 10; % new line
TAB = 9; % tab
n = length(line);
b = ((line ~= ' ') & (line ~= CR) & (line ~= NL) & (line ~= TAB)); % space->0, non-space->1
for i = 1:length(sep_chars)
  b = b & (line ~= sep_chars(i));
end

if (length(b) > 0)
  db = diff([0,b,0]);
  s = find(db == 1);
  e = find(db == -1)-1;
else
  % Whitespace line
  s = [];
  e = [];
end

