function status = url_get(ucell, ARG2)
% URL_GET: url_get(ucell, odir);
% URL_GET: url_get(ucell, ocell);
%
% Get data (typically images) from a set of URL's specified in the url cell array.
%
% INPUT:
% -----
% ucell - cell array with URL of data files to get
% odir  - directory to put files in
%
% HISTORY:
% -------
% 20070510 (MCB) - Added option to allow ARG2 to be a cell array with output names
% 20060825 (MCB) - Based in part on Charless Fowlkes' wwwimread.m
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% pfx.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
 
N = size(ucell, 1);
if (nargout > 0)
  status = zeros(N,1);
end

if (iscell(ARG2))
  opmode = 1;
  if (size(ARG2,1) ~= N)
    fprintf(1, 'ERROR (url_get): size of ucell and ocell must match\n');
    return;
  end
else
  opmode = 0;
end

for n = 1:N
  url = ucell{n,1};
  
  if (opmode == 1)
    ofile = ARG2{n,1};
  else
    L = length(url);
    [p,f,x] = pfx(url);
    ofile = [ARG2, url(f:L)];
  end
  
  % Use wget to retrieve
  cmd = ['wget ', url, ' -O ', ofile];
    
  [s,w] = unix(cmd);

  if (s ~= 0)
    fprintf(1, 'WARNING (url_get): command = |%s| failed\n', cmd);
    if (nargout > 1)
      status(n,1) = s;
    end
  end
end
