function V = voxelize_polyhedrons(Pn, xrange, yrange, zrange)
%
% voxelize_polyhedrons: V = voxelize_polyhedrons(Pn, xrange, yrange, zrange);
%
% INPUT:
% -----
% Pn     - polyhedrons in normals form
% xrange - 3 element vector (x0, xstep, x1) 
% yrange - 3 element vector (y0, ystep, y1) 
% zrange - 3 element vector (z0, zstep, z1) 
%
% OUTPUT:
% ------
% V
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% sample_count.m
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

EPS = 1e-07;

% fname = '/proj/og1/biology/aroeder/data/files-for-mike-burl/f2.txt';
%Pf = read_polyhedrons(fname);
%Pn = facets_to_normals(Pf, 0); % Convert to normals form; Bruce has left-handed
n_cells = size(Pn,1);
nx = sample_count(xrange(1), xrange(2), xrange(3));
ny = sample_count(yrange(1), yrange(2), yrange(3));
nz = sample_count(zrange(1), zrange(2), zrange(3));
fprintf(1, 'nx = %d, ny = %d, nz = %d\n', nx, ny, nz);

V = zeros(nx, ny, nz);

for i = 1:nx
  x = xrange(1) + xrange(2) * (i-1);
  for j = 1:ny
    y = yrange(1) + yrange(2) * (j-1);
    for k = 1:nz
      z = zrange(1) + zrange(2) * (k-1);
      for n = 1: n_cells % for each polytope
        A = Pn{n,1};
	% test whether [x;y;z] is inside (or exactly on surface)
        b = A * [x; y; z; -1];
	if (all(b <= EPS))
	  V(i,j,k) = n;
	  break
	end
      end
    end
  end
end
      
