function A = vread(filename);
%
% VREAD: A = vread(filename);
%
% Reads view-format files into matlab. The VIEW format was developed by 
% Jim Brase at LLNL. It is a convenient binary format for representing
% multidimensional data arrays. Various precisions from unsgined character
% to double are supported.
%
% INPUT:
% -----
% filename - string with name of file 
%              (You may use the .sdt extension or provide no extension)
%
% OUTPUT:
% ------
% A - data matrix
%
% HISTORY:
% -------
% 20031117 (MCB) - Added stripping of .sdt extension if it is included
%           on filename.
%
% 20010111 (MCB) - Modified so that in reading binary .sdt file the 
%            Big-endian convention is assumed. Had been having trouble
%            with cross-platform (Sun vs Intel) reading of view files.
%            This should fix it.
%
% Author:    M.C. Burl
% Copyright: Jet Propulsion Laboratory, California Institute of Technology
% Date:      1992--2001
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

% Strip the .sdt extension if it is given on filename
L = length(filename);
if (L >= 4)
  if (filename(L-3:L) == '.sdt')
    filename = filename(1:L-4);
  end
end

% Read parameter file to find number of rows, columns, and precision
pfile = sprintf('%s.spr', filename);
idp = fopen(pfile);
ndim = fscanf(idp, '%d', 1);
if (ndim ~= 2)
  error('Can only read two dimensional data');
end
nc   = fscanf(idp, '%d', 1);  
junk = fscanf(idp, '%f', 1);
junk = fscanf(idp, '%f', 1);
nr   = fscanf(idp, '%d', 1);
junk = fscanf(idp, '%f', 1);
junk = fscanf(idp, '%f', 1);
type = fscanf(idp, '%d', 1);
fclose(idp);

if (type == 0)
  precision = 'unsigned char';
elseif (type == 1)  
  precision = 'int16';
elseif (type == 2)
  precision = 'int';
elseif (type == 3) 
  precision = 'float';
elseif (type == 5)
  precision = 'double';
else 
  error('Unrecognized data type');
end

% Read binary data file
dfile = sprintf('%s.sdt', filename);
idd = fopen(dfile, 'r', 'ieee-be');
A = (fread(idd, [nc, nr], precision))';
fclose(idd);
