function vwrite(filename, A, type);
%
% VWRITE: vwrite(filename, A, type);
%
% Write view-format files from matlab.
%
% INPUT:
% -----
% filename - string with desired name (and path) of output file.
%              (Use either the .sdt extension or no extension in filename)
% A        - matrix contiaining the data
% type     - argument to specify the precision
%
%            type = 0  -> byte
%            type = 2  -> int
%            type = 3  -> float
%            type = 5  -> double
%
% HISTORY:
% -------
% 2008/02/24 (MCB) - Changed default type to double
%             Added safety check to prevent reversal of arg1 and arg2.
% 2006/07/26 (MCB) - Fixed so that '.sdt' extension could be included or not.
% 2001/01/11 (MCB) - Modified vwrite to explicitly open .sdt file with Big-endian
%             convention. Had been having trouble between Sun/Intel interpretation
%             of bytes in sdt file.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------
[nr, nc] = size(A);

if (nargin == 2)
  type = 5;
end

if (~isstr(filename))
  fprintf(1, 'ERROR (vwrite): filename (arg1) must be character array\n');
  return
end

% Strip the .sdt extension if it is given on filename
L = length(filename);
if (L >= 4)
  if (filename(L-3:L) == '.sdt')
    filename = filename(1:L-4);
  end
end

if (type == 0)
  precision = 'unsigned char';
elseif (type == 2)
  precision = 'int';
elseif (type == 3) 
  precision = 'float';
elseif (type == 5)
  precision = 'double';
else 
  error('Unrecognized data type');
end

junk = 0.0;

% Write parameter file -  number of rows, columns, precision, etc
pfile = sprintf('%s.spr', filename);
idp = fopen(pfile, 'w');
fprintf(idp, '%d\n', 2);   %ndim
fprintf(idp, '%d\n', nc);  
fprintf(idp, '%f\n', 0.0);
fprintf(idp, '%f\n', 1.0);
fprintf(idp, '%d\n', nr);
fprintf(idp, '%f\n', 0.0);
fprintf(idp, '%f\n', 1.0);
fprintf(idp, '%d\n', type);
fprintf(idp, '%f\n', 0.0);
fprintf(idp, '%f\n', 0.0);
fclose(idp);

% Write binary data file
dfile = sprintf('%s.sdt', filename);
idd = fopen(dfile, 'w', 'ieee-be');
fwrite(idd, A', precision);
fclose(idd);
