function [E, X] = zero_crossings(I)
%
% ZERO_CROSSINGS: [E, X] = zero_crossings(I);
%
% Find zero crossings (list of line segments) from I. Integer coordinates are
% centers of pixels.
%
% NOTE: Doesn't handle the "exactly 0" case quite right.
%
%---------------------------------------------------------------------------------------
% BEGIN CDS DEPENDENCIES
% END CDS DEPENDENCIES
%---------------------------------------------------------------------------------------

[nr, nc] = size(I);

H = (I(1:nr, 1:nc-1) .* I(1:nr, 2:nc) < 0);
V = (I(1:nr-1, 1:nc) .* I(2:nr, 1:nc) < 0);

S = H(1:nr-1,1:nc-1) + 4 * H(2:nr,1:nc-1) + 8 * V(1:nr-1,1:nc-1) + 2 * V(1:nr-1,2:nc);

[i,j] = find((S==3) | (S==5) | (S==6) | (S==9) | (S==10) | (S==12));
ne = length(i);
E = zeros(ne, 4);
for e = 1:ne
  x = j(e);
  y = i(e);
  s = S(y,x); 
  if (s == 3)
    dx1 = 1/(1-I(y,x+1)/I(y,x));
    dy2 = 1/(1-I(y+1,x+1)/I(y,x+1));
    E(e, :) = [x+dx1, y, x+1, y+dy2];
  elseif (s ==5)
    dx1 = 1/(1-I(y,x+1)/I(y,x));
    dx4 = 1/(1-I(y+1,x+1)/I(y+1,x));
    E(e, :) = [x+dx1, y, x+dx4, y+1];
  elseif (s==6)
    dx4 = 1/(1-I(y+1,x+1)/I(y+1,x));
    dy2 = 1/(1-I(y+1,x+1)/I(y,x+1));
    E(e, :) = [x+1, y+dy2, x+dx4, y+1];
  elseif (s==9)
    dx1 = 1/(1-I(y,x+1)/I(y,x));
    dy8 = 1/(1-I(y+1,x)/I(y,x));
    E(e, :) = [x+dx1, y, x, y+dy8];
  elseif (s==10)
    dy8 = 1/(1-I(y+1,x)/I(y,x));
    dy2 = 1/(1-I(y+1,x+1)/I(y,x+1));
    E(e, :) = [x, y+dy8, x+1, y+dy2];
  elseif (s==12)
    dx4 = 1/(1-I(y+1,x+1)/I(y+1,x));
    dy8 = 1/(1-I(y+1,x)/I(y,x));
    E(e, :) = [x, y+dy8, x+dx4, y+1];
  end
end

[i,j] = find(S == 15);
nc = length(i);
X = zeros(6*nc, 4);
for c = 1:nc
  x = j(c);
  y = i(c);
  dx1 = 1/(1-I(y,x+1)/I(y,x));
  dy2 = 1/(1-I(y+1,x+1)/I(y,x+1));
  dx4 = 1/(1-I(y+1,x+1)/I(y+1,x));  
  dy8 = 1/(1-I(y+1,x)/I(y,x));  
  X(6*c-5:6*c,:) = [x+dx1, y, x+1, y+dy2;
                    x+1, y+dy2, x+dx4, y+1;
		    x+dx4, y+1, x, y+dy8;
		    x, y+dy8, x+dx1, y;
		    x+dx1, y, x+dx4, y+1;
		    x,y+dy8, x+1, y+dy2];
end
